@@ -1,10 +1,8 @@
 /* swcommon.c -- swbis utility common routines.
 
-  Copyright (C) 2003,2004 James H. Lowe, Jr.  <jhlowe@acm.org> 
-  All Rights Reserved.
-*/
-
-/*
+ Copyright (C) 2003, 2004, 2005, 2006  James H. Lowe, Jr. 
+ All Rights Reserved.
+ 
  COPYING TERMS AND CONDITIONS:
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,6 +23,7 @@
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
+#include "vplob.h"
 #include "strob.h"
 #include "uxfio.h"
 #include "taru.h"
@@ -38,6 +37,7 @@
 #include "swfork.h"
 #include "swcommon.h"
 #include "swevents.h"
+#include "swutillib.h"
 #include "atomicio.h"
 #include "swutilname.h"
 
@@ -69,10 +69,12 @@ is_unix_sys_error(char * sptr)
 		strstr(sptr, "SIGINT") || 
 		strstr(sptr, "ermission denied") || 
 		strstr(sptr, "ot permitted") ||
-		strstr(sptr, "input/output") ||
-		strstr(sptr, "Input/Output") ||
-		strstr(sptr, "i/o") || 
-		strstr(sptr, "I/O") ||
+		strstr(sptr, " input/output") ||
+		strstr(sptr, " Input/Output") ||
+		strstr(sptr, " i/o") || 
+		strstr(sptr, " I/O") ||
+		strstr(sptr, "i/o ") || 
+		strstr(sptr, "I/O ") ||
 		strstr(sptr, " error") ||
 		strstr(sptr, " Error") ||
 		strstr(sptr, "error ") ||
@@ -399,15 +401,15 @@ ERRORCODE * createErrorCode(void)
 
 void destroyErrorCode(ERRORCODE * EC) { free(EC); }
 
-void setErrorCode(ERRORCODE * EC, int code) { EC->codeM = code; }
+void swc_setErrorCode(ERRORCODE * EC, int code, char * msg) { EC->codeM = code; }
 
-int getErrorCode(ERRORCODE * EC) { return EC->codeM; }
+int swc_getErrorCode(ERRORCODE * EC) { return EC->codeM; }
 
 void 
 swc_copyright_info(FILE * fp)
 {
 	fprintf(fp,  "%s",
-"Copyright (C) 2004,2005 Jim Lowe\n"
+"Copyright (C) 2004, 2005, 2006 Jim Lowe\n"
 "Portions are copyright 1985-2000 Free Software Foundation, Inc.\n"
 "This software is distributed under the terms of the GNU General Public License\n"
 "and comes with NO WARRANTY to the extent permitted by law.\n"
@@ -445,6 +447,10 @@ swc_parse_soc_spec(char * arg, char ** selections, char ** target)
 	}
 
 	if (arg[0] != '@') {
+		/*
+		 * this code branch is invalid (never happens) for targets specs and
+		 * not supported for source specs
+		 */
 		*selections = strdup(arg);
 		if ((p = strrchr(*selections, (int) '@')) != NULL) {
 			*p = '\0';
@@ -1049,15 +1055,18 @@ swc_handle_blocked_signals(int sig_set[][2], SHCMD * killcmd,
 	}
 }
 
-SWVERID *
-swc_process_selection_args(char ** argvector,
+int
+swc_process_selection_args(VPLOB * swspec_list, char ** argvector,
 			int uargc,
 			int * poptind)
 {
 	char * s;
 	int count = 0;
+	int error_count = 0;
 	SWVERID * swverid = NULL;
 
+	error_count = 0;
+	if (!swspec_list) return -1;
 	while (*poptind < uargc) {
 		s = argvector[*poptind];
 		if (s && *s == '@') {
@@ -1066,14 +1075,20 @@ swc_process_selection_args(char ** argvector,
 		(*poptind)++;
 		count++;
 		swverid = swverid_open(NULL, s);
+		if (swverid == NULL) {
+			fprintf(stderr, "%s: error processing software selection: %s\n", swlib_utilname_get(), s);
+			 (error_count)++;
+		} else {
+			vplob_add(swspec_list, (void*)swverid);
+		}
 	}
-	if (count > 1) {
-		fprintf(stderr,
-			"%s: multiple sw specs not supported\n",
-			swlib_utilname_get());
-		return NULL;
-	}
-	return swverid;
+	return error_count;
+}
+
+int
+swc_read_selections_file(void)
+{
+	return 0;
 }
 
 char *
@@ -1149,7 +1164,7 @@ swc_get_next_target(char ** argvector,
 		*pnum_remains = 1;  /* assume more that one target */
 		n = swgp_read_line(fd, (STROB*)tmp);
 		if (n > 0) {
-			if (process_targetfile_line(tmp, &current_arg) > 1) {
+			if (process_targetfile_line(tmp, &current_arg) >= 1) {
 				current_arg = strdup(current_arg);
 				strob_close(tmp);
 				return current_arg;
@@ -1370,3 +1385,36 @@ swc_get_pax_read_command(struct g_pax_read_command g_pax_read_commands[],
 				paxdefault, 
 				verbose_level, keep, DEFAULT_PAX_R);
 }
+
+int
+swc_process_swoperand_file(SWUTIL * swutil,
+		char * type_string,
+		char * filename, 
+		int * p_stdin_in_use,
+		int * p_array_index,
+		int * fd_array)
+{
+	int list_fd;
+	if (strcmp(filename, "-") == 0) {
+		(*p_stdin_in_use)++;
+		list_fd = STDIN_FILENO;
+	} else {
+		list_fd = open(
+			filename,
+			O_RDONLY, 0);
+		if (list_fd < 0) {
+			swutil_doif_writef2(swutil, swutil->swu_fail_loudlyM,
+				"error opening %s list file\n", type_string);
+				return -1;
+		}
+	}
+	if (*p_array_index >= 
+			SWC_TARGET_FD_ARRAY_LEN - 2) {
+		swutil_doif_writef2(swutil, swutil->swu_fail_loudlyM,
+			"too many %s files\n", type_string);
+		return -1;
+	}
+	fd_array[(*p_array_index)++] = list_fd;
+	fd_array[(*p_array_index)] = -1;
+	return 0;
+}
