@@ -23,9 +23,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "vplob.h"
 #include "usgetopt.h"
 #include "swcommon0.h"
 #include "swextopt.h"
+#include "swutillib.h"
 #include "swverid.h"
 
    void swc_copyright_info(FILE * fp);
@@ -105,7 +107,7 @@
    pid_t swc_fork_logger(STROB *, STROB *, int efd, int ofd, struct sw_logspec *,
 			int * s_efd, int * t_efd, int verboselevel, int * pfd_array);
 
-   SWVERID * swc_process_selection_args(char ** argvector, int uargc, int * poptind);
+   int swc_process_selection_args(VPLOB * , char ** argvector, int uargc, int * poptind);
 
    void swc_flush_logger(STROB * slinebuf, STROB * tlinebuf, int efd,
 			int ofd, struct sw_logspec *, int verboselevel);
@@ -116,5 +118,7 @@
    int swc_open_logfile(char * logfile);
    void swc_initialize_logspec(struct sw_logspec * logspec, char * logfile, int log_level);
    
+   int swc_process_swoperand_file(SWUTIL * swutil, char * type_string, char * filename,
+			int * p_stdin_in_use, int * p_array_index, int * fd_array);
 
 #endif
