@@ -16,6 +16,8 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,6 +28,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "strob.h"
+#include "cplob.h"
+#include "vplob.h"
 #include "swlib.h"
 #include "usgetopt.h"
 #include "ugetopt_help.h"
@@ -49,10 +54,26 @@
 #include "atomicio.h"
 #include "swutilname.h"
 
+#include "debug_config.h"
+#ifdef SWINSTALLNEEDDEBUG
+#define SWINSTALL_E_DEBUG(format) SWBISERROR("SWINSTALL DEBUG: ", format)
+#define SWINSTALL_E_DEBUG2(format, arg) SWBISERROR2("SWINSTALL DEBUG: ", format, arg)
+#define SWINSTALL_E_DEBUG3(format, arg, arg1) SWBISERROR3("SWINSTALL DEBUG: ", format, arg, arg1)
+#else
+#define SWINSTALL_E_DEBUG(arg)
+#define SWINSTALL_E_DEBUG2(arg, arg1)
+#define SWINSTALL_E_DEBUG3(arg, arg1, arg2)
+#endif /* SWINSTALLNEEDDEBUG */
+
 extern struct g_pax_read_command g_pax_read_commands[];
+
+/*
+ * These are required by the TEVENTS routine
+ */
 extern struct swEvents eventsArray[];
 static struct swEvents * g_evnt = eventsArray;
 
+
 #define SWBIS_DEFAULT_REVISION "0.0"
 
 #define SCARY_ARRAY_LEN 200
@@ -206,7 +227,7 @@ audit_execution_scripts(SWI * swi, SCARY ** scary_scripts)
 	for (;tag=(*ts),*ts != (char*)NULL; ts++) {	
 		product_xxinstall_script = swi_product_get_control_script_by_tag(product, tag);
 		if (product_xxinstall_script) {
-			scary_script = scary_create(tag, product->tagM, product_xxinstall_script);
+			scary_script = scary_create(tag, product->baseM.tagM, product_xxinstall_script);
 			scary_add(scary_scripts, scary_script);
 		}
 	}
@@ -219,7 +240,7 @@ audit_execution_scripts(SWI * swi, SCARY ** scary_scripts)
 	fileset_index = 0;
 	fileset = swi_product_get_fileset(product, fileset_index++);
 	while(fileset) {	
-		strob_sprintf(tagspec, STROB_NO_APPEND, "%s.%s", product->tagM, fileset->tagM);
+		strob_sprintf(tagspec, STROB_NO_APPEND, "%s.%s", product->baseM.tagM, fileset->baseM.tagM);
 		ts = execution_scripts;
 		for (;tag=(*ts),*ts != (char*)NULL; ts++) {	
 			fileset_xxinstall_script = swi_xfile_get_control_script_by_tag(fileset, tag);
@@ -274,7 +295,7 @@ write_control_script_code_fragment(SWI * swi, SWI_CONTROL_SCRIPT * script, char
 	strob_sprintf(tmp, STROB_DO_APPEND,
 		"%s %s",
 		swspec_tags,
-		script->tagM);
+		script->baseM.tagM);
 
 	strob_sprintf(buf, STROB_DO_APPEND,
 		"	# Generated by swinstall_lib.c:write_control_script_code_fragment\n"
@@ -293,7 +314,7 @@ write_control_script_code_fragment(SWI * swi, SWI_CONTROL_SCRIPT * script, char
 		swi->swi_pkgM->catalog_entryM,
 		TEVENT(2, (swi->verboseM), SW_CONTROL_SCRIPT_BEGINS, strob_str(tmp)),
 		swspec_tags,
-		script->tagM,
+		script->baseM.tagM,
 		TEVENT(2, (swi->verboseM), SW_CONTROL_SCRIPT_ENDS, "status=$sw_retval")
 		);
 	
@@ -322,10 +343,10 @@ write_case_block(SWI * swi, STROB * buf, char * tag)
 }
 
 static
-int
-get_whole_block_size(int size)
+unsigned long int
+get_whole_block_size(unsigned long int size)
 {
-	int ret;
+	unsigned long int ret;
 	ret = ((size / TARRECORDSIZE) + 1) * TARRECORDSIZE;
 	return ret;
 }
@@ -403,7 +424,7 @@ load_single_file_tar_archive (
 	)
 {
 	int ret;
-	int stdin_file_size;
+	unsigned long int stdin_file_size;
 	STROB * tmp;
 	STROB * namebuf;
 
@@ -418,7 +439,7 @@ load_single_file_tar_archive (
 	/* (*f_archive_data)(tmp, swi); */
 
 	stdin_file_size = \
-		get_whole_block_size(strlen(data)) +  /* data plue tar block padding */
+		get_whole_block_size((unsigned long int)strlen(data)) +  /* data plue tar block padding */
 		TARRECORDSIZE + /* ustar header */
 		TARRECORDSIZE + /* trailer block */
 		TARRECORDSIZE + /* trailer block */
@@ -469,8 +490,8 @@ load_single_file_tar_archive (
 	 * Assert what must be true.
 	 */
 
-	if (ret != stdin_file_size) {
-		fprintf(stderr, "ret=%d  stdin_file_size=%d\n", ret, stdin_file_size);
+	if (ret != (int)stdin_file_size) {
+		fprintf(stderr, "ret=%d  stdin_file_size=%lu\n", ret, stdin_file_size);
 		SWBIS_ERROR_IMPL();
 		SWI_internal_error();
 		return -1;
@@ -675,7 +696,7 @@ construct_prepost_script(STROB * buf, SWI * swi, char * script_tag)
 			swi->swi_pkgM->target_pathM);
 		construct_script(buf, swi,
 			product_xxinstall_script,
-			product->tagM,
+			product->baseM.tagM,
 			event_error_value,
 			event_warning_value);
 	}
@@ -694,7 +715,7 @@ construct_prepost_script(STROB * buf, SWI * swi, char * script_tag)
 		"	0)\n"
 		);
 
-		strob_sprintf(tmp, 0, "%s.%s", product->tagM, fileset->tagM);
+		strob_sprintf(tmp, 0, "%s.%s", product->baseM.tagM, fileset->baseM.tagM);
 		strob_sprintf(buf, STROB_DO_APPEND, "\tcd \"%s\"\n", swi->swi_pkgM->target_pathM);
 		construct_script(buf, swi,
 			fileset_xxinstall_script,
@@ -738,7 +759,7 @@ construct_analysis_script(STROB * buf, SWI * swi, SWI_CONTROL_SCRIPT ** p_script
 	
 		script = swi_product_get_control_script_by_tag(prod, SW_A_checkinstall);
 		SWLIB_ASSERT(script != NULL);
-		ret = write_control_script_code_fragment(swi, script, prod->tagM, buf);
+		ret = write_control_script_code_fragment(swi, script, prod->baseM.tagM, buf);
 		SWLIB_ASSERT(ret == 0);
 
 		/*
@@ -1162,7 +1183,7 @@ get_attribute(SWHEADER * header, char * att, int * len)
 {
 	char * line;
 	char * value;
-        line = swheader_get_attribute_single_value(header, att);
+        line = swheader_get_attribute(header, att);
 	value = swheaderline_get_value(line, len);
 	return value;
 }
@@ -1203,7 +1224,7 @@ SWHEADER *
 get_global_index_header(SWI * swi)
 {
 	SWHEADER * ret;
-	ret = swi->swi_pkgM->headerM;
+	ret = swi->swi_pkgM->baseM.global_headerM;
 	return ret;
 }
 
@@ -1212,7 +1233,7 @@ SWHEADER *
 get_fileset_info_header(SWI * swi)
 {
 	SWHEADER * ret;
-	ret = swi->swi_pkgM->swi_coM[0]->swi_coM[0]->headerM;
+	ret = swi->swi_pkgM->swi_coM[0]->swi_coM[0]->info_headerM;
 	return ret;
 }
 
@@ -1241,14 +1262,15 @@ get_fileset_file_count(SWHEADER * infoheader)
 }
 
 static
-int
-get_delivery_size(SWI * swi)
+unsigned long int
+get_delivery_size(SWI * swi, int * result)
 {
-	int size;
+	unsigned long int size;
 	int count;
 	char * obj;
 	char * line;
 	char * value;
+	int atoi_error;
 	SWHEADER * indexheader = get_global_index_header(swi);
 	SWHEADER * infoheader = get_fileset_info_header(swi);
 
@@ -1263,17 +1285,26 @@ get_delivery_size(SWI * swi)
 	/*
 	 * Get the size attribute from the fileset.
 	 */
+	*result = 0;
 	swheader_reset(indexheader);
-        obj = swheader_get_object_by_tag(indexheader, "fileset", "" );
-        line = swheader_get_attribute_single_value(indexheader, "size");
+        obj = swheader_get_object_by_tag(indexheader, "fileset", "*" );
+        line = swheader_get_attribute(indexheader, "size");
 	value = swheaderline_get_value(line, NULL);
 
 	if (!value) {
 		SWLIB_FATAL("fileset.size attribute is missing");
 	}
 
-	size = atoi(value);
+	size = swlib_atoul(value, &atoi_error);
+	if (atoi_error) {
+		*result = -1;
+		return 0;  /* return a safe value */	
+	}
 	count = get_fileset_file_count(infoheader);
+	if (count < 0) {
+		SWLIB_FATAL("");
+	}
+
 	size = 	size + 			/* the fileset size value */
 		(count * 2048) +	/* header and last block for every file + 1024 extra pad */
 		(10 * 512);		/* trailer blocks, 10 is arbitrary */
@@ -2064,7 +2095,7 @@ remove_catalog_directory(SWI * swi, int ofd,
 	 */
 
 	strob_strcpy(path, swi->exported_catalog_prefixM);
-	if (swlib_is_clean_relative_path(strob_str(path))) return 1;
+	if (swlib_check_clean_relative_path(strob_str(path))) return 1;
 	swlib_squash_trailing_slash(strob_str(path));
 	if (strstr(strob_str(path), SW_A_catalog) == NULL) return 2;
 
@@ -2346,6 +2377,7 @@ swinstall_get_utsname_attributes(SWI * swi, int ofd, int event_fd)
 			TEVENT(2, 1/*verbose level*/, SWI_ATTRIBUTE, "os_release=\"$(uname -r)\""),
 			TEVENT(2, 1, SWI_ATTRIBUTE, "os_version=\"$(uname -v)\""),
 			"");
+	E_DEBUG2("get_utsname_script=[%s]", strob_str(tmp));
 
 	/* TS_uts_query */
 	ret = swicol_rpsh_task_send_script(
@@ -2370,6 +2402,18 @@ swinstall_get_utsname_attributes(SWI * swi, int ofd, int event_fd)
 	if (swi->debug_eventsM)
 		swicol_show_events_to_fd(swi->swicolM, STDERR_FILENO, -1);
 
+	/*
+	 * print the events to memory
+	 */
+        swicol_print_events(swi->swicolM, tmp, swi->swicolM->event_indexM);
+
+	/*
+	 * Parse and Store the uts attributes
+	 */
+	swuts_read_from_events(swi->version_idM->swutsM, strob_str(tmp));
+
+	E_DEBUG2("utsname=[%s]", strob_str(tmp));
+
 	if (ret != 0) {
 		;
 		/*
@@ -2473,7 +2517,7 @@ construct_execution_phase_script(SWI * swi,
 static
 int
 arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
-	int * deadman, char * target_path, char * catalog_path, SWVERID * swspec,
+	int * deadman, char * target_path, char * catalog_path, VPLOB * swspecs,
 	int section, int altofd, int opt_preview,
 	char * pax_read_command_key, int alt_catalog_root, int event_fd,
 	struct extendedOptions * opta, struct sw_logspec * logspec,
@@ -2486,6 +2530,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	int read_header_ret;
 	int retval = 0;
 	int cmpret = 0;
+	int size_result;
 	char * current_path;
 	char * current_type;
 	char * current_link_source;
@@ -2500,6 +2545,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	int files_loading_verbose;
 	int filecount;
 	int optacc_a;
+	int atoi_error;
 	STROB * resolved_path;
 	STROB * namebuf;
 	STROB * newnamebuf;
@@ -2525,7 +2571,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	int curpos;
 	int did_fileset = 0;
 	int fileset_write_ret = 0;
-	int payload_size;
+	unsigned long int payload_size;
 	unsigned long filesize;
 	int eoa;
 	int header_ret;
@@ -2588,7 +2634,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	
 	log_level_str = get_opta(opta, SW_E_loglevel);
 	SWLIB_ASSERT(log_level_str != NULL);
-	log_level = atoi(log_level_str);	
+	log_level = swlib_atoi(log_level_str, &atoi_error);	
 
 	files_loading_verbose = (
 				(keep_old_files ? keep_old_files : (swi->verboseM - SWC_VERBOSE_7)) ||
@@ -2620,12 +2666,12 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	/*
 	 * Get the fileset size.
 	 */
-	payload_size = get_delivery_size(swi);
+	payload_size = get_delivery_size(swi, &size_result);
+	if (size_result) {
+		SWBIS_ERROR_IMPL();
+		return -31;
+	}
 		
-	/*
-	fprintf(stderr, "Delivery size is %d bytes\n", payload_size);
-	*/
-
 	/*
 	 * write the script to the target.
 	 */
@@ -2705,6 +2751,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	while ((read_header_ret = xformat_read_header(xformat)) > 0 &&
 			(!deadman || (deadman && *deadman == 0))) {
 		
+		SWINSTALL_E_DEBUG("HERE");
 		if (xformat_is_end_of_archive(xformat)){
 			/*
 			 * This is an unexpected error
@@ -2736,11 +2783,11 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		 * Show the parsed path components
 		 */
 		swpath_shallow_fill_export(swpath_ex, swpath); 
-		if (swi->verboseM >= SWC_VERBOSE_8)
+		if (swi->verboseM >= SWC_VERBOSE_0) {
 			swlib_doif_writef(swi->verboseM, SWC_VERBOSE_8,
 				logspec, efd, "%s",
 					swpath_ex_print(swpath_ex, tmp_swpath_ex, ""));
-
+		}
 		is_catalog = swpath_get_is_catalog(swpath);
 
 		if (is_catalog == SWPATH_CTYPE_DIR) {
@@ -2760,6 +2807,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			/*
 			 * Examine the catalog for signature.
 			 */
+			SWINSTALL_E_DEBUG("HERE");
 			did_catalog_tar = 1;
 			swi_examine_signature_blocks(swi->swi_pkgM->dfilesM,
 					&sig_block_start, &sig_block_end);
@@ -2806,6 +2854,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * there are no signatures.
 			 * =====================================
 			 */
+			SWINSTALL_E_DEBUG("HERE");
 			did_sigfiles = 1;
 			if (opt_preview == 0) {
 				/* TS_sig_load */
@@ -2817,6 +2866,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 				SWBIS_ERROR_IMPL();
 				return -42;
 			}
+			ret = xformat_copy_pass(xformat, swi->nullfdM, ifd);
 		} else if (
 			did_sigfiles == 0 &&
 			package_is_signed > 0 &&
@@ -2828,6 +2878,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 *	 <catalog_path>/export/catalog.tar.sig
 			 *	 <catalog_path>/export/catalog.tar.sigN
 			 */
+			SWINSTALL_E_DEBUG("HERE");
 			did_sigfiles = 1;
 			filesize = xformat_get_filesize(xformat);	
 
@@ -2860,6 +2911,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * Read past the remainder of the catalog files.
 			 * =====================================
 			 */
+			SWINSTALL_E_DEBUG("HERE");
 			ret = xformat_copy_pass(xformat, swi->nullfdM, ifd);
 			if (ret < 0) {
 				SWBIS_ERROR_IMPL();
@@ -2868,14 +2920,17 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			/*
 			 * Now ready to deal with the storage section.
 			 */		
+			SWINSTALL_E_DEBUG("HERE");
 			break;
 		}
 	} /* while */
 
+	SWINSTALL_E_DEBUG("HERE");
 	if (read_header_ret < 0) {
 		SWBIS_ERROR_IMPL();
 		return -50;
 	}
+	SWINSTALL_E_DEBUG("HERE");
 
 	/*
 	 * Good, made it this far..
@@ -2891,6 +2946,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	 */
 
 	if (opt_preview == 0) {
+		SWINSTALL_E_DEBUG("HERE");
 		/* TS_catalog_unpack */
 		ret = unpack_catalog_tarfile(swi, vofd, catalog_path, pax_read_command, alt_catalog_root, event_fd);
 		if (ret) retval ++;
@@ -2905,6 +2961,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 
 	if (opt_preview == 0) {
 		/* TS_session_options */
+		SWINSTALL_E_DEBUG("HERE");
 		ret = write_tar_session_options_file(
 			swi,
 			vofd,
@@ -2926,6 +2983,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 
 	if (opt_preview == 0) {
 		/* TS_load_controlsh */
+		SWINSTALL_E_DEBUG("HERE");
 		ret = write_tar_controlsh_file(
 			swi,
 			vofd,
@@ -2943,6 +3001,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		/*
 		 * TS_analysis_002
 		 */
+		SWINSTALL_E_DEBUG("HERE");
 		ret = run_analysis_script(swi, vofd, event_fd);
 		if (ret) retval ++;
 	}
@@ -2959,6 +3018,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		/*
 		 * Audit the control_scripts that must be run
 		 */
+		SWINSTALL_E_DEBUG("HERE");
 		audit_execution_scripts(swi, g_script_array);
 		
 		update_fileset_state(swi, "*", SW_STATE_TRANSIENT);
@@ -2978,6 +3038,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	 * Send the task script for the fileset.
 	 * =======================================
 	 */
+	SWINSTALL_E_DEBUG("HERE");
 	did_fileset = 1;	
 	strob_strcpy(newnamebuf, target_path);
 	strob_sprintf(tmp, 0,
@@ -2990,6 +3051,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	ret = 0;
 	if (opt_preview == 0) {
 		/* TS_execution_phase */
+		SWINSTALL_E_DEBUG("HERE");
 		ret = construct_execution_phase_script(swi,
 				 execution_phase_script,
 				pax_read_command);
@@ -3003,6 +3065,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	}
 
 	if (ret < 0) {
+		SWINSTALL_E_DEBUG("HERE");
 		return -1;
 	}
 
@@ -3021,10 +3084,11 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		 * has just been read.  This happens with HP-UX
 		 * packages.
 		 */
+		SWINSTALL_E_DEBUG("HERE HP style package");
 		if (uxfio_lseek(ifd, -512, SEEK_CUR) < 0) {
 			SWI_internal_fatal_error();
 		}
-	}	
+	}
 
 	/*
 	 * =====================================
@@ -3036,6 +3100,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		xformat_read_header(xformat) > 0 &&
 		(!deadman || (deadman && *deadman == 0))
 	) {
+		SWINSTALL_E_DEBUG("HERE: Storage");
 		if (xformat_is_end_of_archive(xformat)){
 			break;
 		}
@@ -3074,19 +3139,23 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * current position of the infoheader.
 			 * This is an optimization path.
 			 */
+			SWINSTALL_E_DEBUG("HERE: Storage");
 			obj = swheader_get_object_by_tag(infoheader, SW_OBJ_file, current_path);
 		} else {
 			/*
 			 * this is the failsafe code path
 			 */
+			SWINSTALL_E_DEBUG("HERE: Storage");
 			obj = (char*)NULL;
 		}	
 
 		if (obj == (char*)(NULL)) {
+			SWINSTALL_E_DEBUG("HERE: Storage");
 			swheader_reset(infoheader);
 		}
 	
 		if (current_path && strlen(current_path)) {
+			SWINSTALL_E_DEBUG("HERE: Storage");
 			if (obj == (char*)NULL) {
 				obj = swheader_get_object_by_tag(infoheader, SW_OBJ_file, current_path);
 			}
@@ -3102,7 +3171,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			}
 
 			current_file_offset = swheader_get_current_offset(infoheader);
-			current_type = swheader_get_attribute_single_value(infoheader, "type");
+			current_type = swheader_get_attribute(infoheader, "type");
 			current_type = swheaderline_get_value(current_type, NULL);
 			swheader_set_current_offset(infoheader, current_file_offset);
 
@@ -3121,7 +3190,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * * to seek back or reset and find the object again.
 			 *
 			 * swheader_reset(infoheader);
-			 * obj = swheader_get_object_by_tag(infoheader, "file", swpath_get_pathname(swpath));
+			 * obj = swheader_get_object_by_tag(infoheader, SW_OBJ_file, swpath_get_pathname(swpath));
 			 */
 			
 			/*
@@ -3238,7 +3307,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * Set the link name.
 			 */
 			if (*current_type == SW_ITYPE_h || *current_type == SW_ITYPE_s) {
-				current_link_source = swheader_get_attribute_single_value(infoheader, "link_source");
+				current_link_source = swheader_get_attribute(infoheader, "link_source");
 				current_link_source = swheaderline_get_value(current_link_source, NULL);
 				swheader_set_current_offset(infoheader, current_file_offset);
 				if (!current_link_source) { SWI_internal_error(); return -68; }
@@ -3407,12 +3476,14 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			/*
 			 * This code path occurs for storage section control directories.
 			 */	
+			SWINSTALL_E_DEBUG("HERE: Storage");
 			ret = 0;
 		}
 		optacc_a = 0;
 		if (ret < 0) {
 			SWBIS_ERROR_IMPL();
 		}
+		SWINSTALL_E_DEBUG("HERE: Storage");
 	} /* while */
 
 	if (cmpret) {
@@ -3442,11 +3513,11 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 
 	if (swi->verboseM > SWC_VERBOSE_10)
 	{
-		fprintf(stderr, "payload size = %d fileset_write_size =%d \n",  payload_size, fileset_write_ret);
-		fprintf(stderr, "pad amount = %d\n",  payload_size - fileset_write_ret);
+		fprintf(stderr, "payload size = %lu fileset_write_size =%d \n",  payload_size, fileset_write_ret);
+		fprintf(stderr, "pad amount = %lu\n",  payload_size - fileset_write_ret);
 	}
 
-	padamount = payload_size - fileset_write_ret;
+	padamount = (int)(payload_size - fileset_write_ret);
 	ret = swlib_pad_amount(vofd, padamount);
 	if (ret != padamount) {
 		SWBIS_ERROR_IMPL();
@@ -3600,8 +3671,8 @@ write_target_install_script(
 	SWLIB_ASSERT(fp_targetpath != NULL);
 	targetpath = strdup(fp_targetpath);
 
-	if (swlib_is_safe_path(targetpath)) { return 2; }
-	if (swlib_is_safe_path(sourcepath)) { return 3; }
+	if (swlib_check_safe_path(targetpath)) { return 2; }
+	if (swlib_check_safe_path(sourcepath)) { return 3; }
 	
 	catalogpathlist = strar_open();
 	buffer = strob_open(1);
@@ -3624,14 +3695,6 @@ write_target_install_script(
 	if (swlib_is_sh_tainted_string(distdata->catalog_bundle_dir1M)) { return 2; }
 	idx = 0;
 
-	if (alt_catalog_root && *installed_software_catalog == '\0') {
-		/*
-		 * apply '-r' option
-		 * Do nothing, -r in swinstall has no effect.
-		 */
-		;
-	}
-
 	/*
 	 * Always treat the installed_software catalog path
 	 * as being relative to the target_path
@@ -3788,7 +3851,7 @@ write_target_install_script(
 	"				mkdir -p \"$xtarget\"\n"
 	"				sw_retval=$?\n"
 	"			else\n"
-	"				xtarget=/tmp/swbis-internal-error-no-way\n"
+	"				xtarget=/\n"
 	"				sw_retval=1\n"
 	"			fi\n"
 	"		else\n"
@@ -4021,7 +4084,7 @@ swinstall_write_target_install_script(
 
 int
 swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview, int * deadman,
-	char * target_path, char * catalog_prefix, SWVERID * swspec,
+	char * target_path, char * catalog_prefix, VPLOB * swspecs,
 	int section, int altofd, int opt_preview, char * pax_read_command_key,
 	int alt_catalog_root, int event_fd, struct extendedOptions * opta,
 	struct sw_logspec * logspec, int keep_old_files, unsigned long int * pstatbytes)
@@ -4050,8 +4113,8 @@ swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview, int * deadman,
 	 */
 	
 	if (
-		swlib_is_clean_absolute_path(swi->swi_pkgM->target_pathM) ||
-		swlib_is_clean_path(swi->swi_pkgM->catalog_entryM) ||
+		swlib_check_clean_absolute_path(swi->swi_pkgM->target_pathM) ||
+		swlib_check_clean_path(swi->swi_pkgM->catalog_entryM) ||
 		0
 	) {
 		return 2;
@@ -4078,7 +4141,7 @@ swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview, int * deadman,
 		 * All tar formats
 		 */
 		ret = arfinstall_tar(swi, ofd, efd, do_preview, deadman,
-				target_path, catalog_prefix, swspec,
+				target_path, catalog_prefix, swspecs,
 				section, altofd, opt_preview, pax_read_command_key,
 				alt_catalog_root, event_fd, opta, logspec, keep_old_files, pstatbytes);
 	} else {
