@@ -106,7 +106,7 @@ class swExCat: public swObjFiles_i
 
 		if (!found || !prod1 || strcmp(prod1->getObjectName(), "product")) {
 			fprintf(stderr, "internal error in write_first_product_directory\n");
-			setErrorCode(10941);
+			setErrorCode(10941, NULL);
 			return;
 		}
 		
