@@ -170,7 +170,7 @@ class swExDistribution: public swExCat
 
 		path = swdef->find("control_directory");
 		if (path == NULL) {
-			path = swdef->find("tag");
+			path = swdef->find(SW_A_tag);
 		}
 		if (path == NULL || ::strlen(path) == 0 || strcmp(path, "/") == 0) return;
 
@@ -181,7 +181,7 @@ class swExDistribution: public swExCat
 			getLeadingDirModeString(),
 			getLeadingDirOwner() /* swdef->find(SWBIS_DISTRIBUTION_OWNER_ATT) */,
 			getLeadingDirGroup() /* swdef->find(SWBIS_DISTRIBUTION_GROUP_ATT) */);
-		if (ret < 0) setErrorCode(20007);
+		if (ret < 0) setErrorCode(20007, NULL);
 		strob_close(tmp);
 	}
 
