@@ -62,7 +62,7 @@ class swExFileset: public swObjFiles_i
 {
 	swPtrList<swPackageFile> * distributionFilesM;
 	STROB * sbufM;
-	int sizeM;
+	unsigned long int sizeM;
       public:
 	
 	swExFileset(char * control_dir): swObjFiles_i(control_dir) {
@@ -260,7 +260,7 @@ class swExFileset: public swObjFiles_i
 
 	void generateFileSetSize(void) {
 		swINFO * info = getInfo();
-		int bytesize = 0;
+		unsigned long int bytesize = 0;
 		swDefinition * inext;
 		swMetaData * att;
 		swDefinition *swdef = getReferer();
@@ -274,14 +274,14 @@ class swExFileset: public swObjFiles_i
 			att = inext->get_next_node();  // The first attribute.
 			while (att) {
 				if ( ::strcmp(att->get_keyword(), SW_A_size) == 0) {
-					bytesize += ::atoi(att->get_value(NULL));
+					bytesize += (unsigned int)(::atoi(att->get_value(NULL)));
 				}
 				att = att->get_next_node();
 			}
 			inext = inext->get_next();
 		}
 		sizeM = bytesize;
-		snprintf(asize, sizeof(asize) -1, "%d", sizeM); 
+		snprintf(asize, sizeof(asize) -1, "%lu", sizeM); 
 		asize[sizeof(asize) - 1] = '\0';
 		swdef->add(SW_A_size, asize);
 		SWEXFILESET_DEBUG("leaving");
@@ -321,7 +321,7 @@ class swExFileset: public swObjFiles_i
 				getCatalogDirModeString(),
 				getCatalogOwner(),
 				getCatalogGroup());
-			if (ret < 0) setErrorCode(20004);
+			if (ret < 0) setErrorCode(20004, NULL);
 		}
 		return;
 	}
@@ -381,7 +381,7 @@ class swExFileset: public swObjFiles_i
 				//
 				// error.
 				//
-				setErrorCode(12302);
+				setErrorCode(12302, NULL);
 				fprintf(stderr, "path attribute not found.\n");
 				return;
 			}
@@ -494,7 +494,7 @@ class swExFileset: public swObjFiles_i
 				fprintf(stderr,
 					"%s: error writing archive member for ( %s ) ret=%d\n",
 					swlib_utilname_get(), strob_str(tmp), ret);
-				setErrorCode(12303);
+				setErrorCode(12303, NULL);
 				return;
 			}
 			swdef = swdef->get_next();
@@ -517,7 +517,7 @@ private:
 		while(swdef) {
 			path=swdef->find(SW_A_path);
 			if (!path) {
-				setErrorCode(12304);
+				setErrorCode(12304, NULL);
 				return NULL;
 			}	
 
@@ -537,7 +537,7 @@ private:
 			}
 			swdef = swdef->get_next();
 		}
-		// setErrorCode(12305);
+		// setErrorCode(12305, NULL);
 		return ret_swdef;
 		// return first_ret_swdef;
 	}
