@@ -75,13 +75,13 @@ class swExProduct: public swExCat
 
 		while((object = containedByIndex(list_index++))) {
 			filesetdef = object->getReferer();
-			if (filesetdef == NULL) { setErrorCode(10801); return; }
+			if (filesetdef == NULL) { setErrorCode(10801, NULL); return; }
 	
 			if (::strcmp(object->getObjectName(), "fileset") != 0)
 				continue;
-			tag = filesetdef->find("tag");
-			if (tag == NULL) { setErrorCode(10802); return; }
-			if (strlen(tag) == 0) { setErrorCode(10803); return; }
+			tag = filesetdef->find(SW_A_tag);
+			if (tag == NULL) { setErrorCode(10802, NULL); return; }
+			if (strlen(tag) == 0) { setErrorCode(10803, NULL); return; }
 			
 			if (strob_strlen(all_filesetsM)) {
 				strob_strcat(all_filesetsM, " ");
@@ -89,7 +89,7 @@ class swExProduct: public swExCat
 			strob_strcat(all_filesetsM, tag);
 		}
 	
-		if (strob_strlen(all_filesetsM) == 0) { setErrorCode(10804); }
+		if (strob_strlen(all_filesetsM) == 0) { setErrorCode(10804, NULL); }
 		swdef->add("all_filesets", strob_str(all_filesetsM));	
 		return;	
 	}
