@@ -53,7 +53,7 @@ class swExStruct_i: public swExStruct
 	STROB * parentPathM;	// The parent path, everything above the control directory.
 	STROB * controlDirectoryM;	// control directory pathname component.
 	STROB * sbufM;			// Used for debugging buffer.
-
+	static STRAR * errorMessagesM;
 	static int outputfdM;		// output file descriptor.
 	static int previewfdM;		//  preview or verbose output uses.
 	static int errorCodeM;		// Global error code. non-zero is bad.
@@ -113,7 +113,27 @@ class swExStruct_i: public swExStruct
 	
 	int getErrorCode(void) { return errorCodeM; }
 
-	void setErrorCode(int c) { errorCodeM = c; }
+	void setErrorCode(int c, char * msg) { 
+		errorCodeM = c; 
+		if (msg)
+			store_error_msg(msg);
+	}
+	
+	void assertNoErrorCondition(int status) {
+		char * s;
+		int ix;
+		if (errorCodeM == 0) return;
+		ix = 0;
+		s = strar_get(errorMessagesM, ix++);
+		while(s) {
+			if (verboseM > 0)	
+				fprintf(stderr, "swpackage: error: %s\n", s);
+                	s = strar_get(errorMessagesM, ix++);
+        	}
+		if (ix < 2)
+			fprintf(stderr, "swpackage: fatal error: code=%d\n", errorCodeM);
+		if (status > 0) exit(status);
+	}
 
 	time_t getCreateTime(void) { return current_timeM; }
 	
@@ -280,7 +300,7 @@ class swExStruct_i: public swExStruct
 		assert(refererM);
 		p = refererM->get_next_node();
 		while(p) {
-			if(!(::strcmp((up=p->get_value((int*)NULL)), "tag"))) {
+			if(!(::strcmp((up=p->get_value((int*)NULL)), SW_A_tag))) {
 				tag=up;
 			}
 			else if(!(::strcmp((up=p->get_value((int*)NULL)),
@@ -361,7 +381,7 @@ class swExStruct_i: public swExStruct
 		}
 		control_dir = swdef->find("control_directory");
 		if (control_dir == static_cast<char*>(NULL)) {
-			control_dir = swdef->find("tag");
+			control_dir = swdef->find(SW_A_tag);
 		}
 		return control_dir;
 	}
@@ -748,6 +768,13 @@ class swExStruct_i: public swExStruct
 	virtual void emitLeadingCatalogDirectory(STROB * tmp)  { }
 
    private:
+
+	void
+	store_error_msg(char * msg)
+	{
+		strar_add(errorMessagesM, msg);
+		return;
+	}
 	
 	void insert_catalog_path(STROB * controlpath) {
 		int len;
@@ -772,7 +799,7 @@ class swExStruct_i: public swExStruct
 		if (strlen(leading_path) && strlen(p)) {
 			al = strstr(p, leading_path);
 			if (al != p) {
-				setErrorCode(10201);
+				setErrorCode(10201, NULL);
 			}
 			len = strlen(leading_path);
 			memmove(p + len + 8, p + len, strlen(p+len)+1);
@@ -808,7 +835,7 @@ class swExStruct_i: public swExStruct
 		if (nullfdM == 0) {
 			nullfdM = open("/dev/null", O_RDWR, 0);
 			if (nullfdM < 0) {
-				setErrorCode(20201);
+				setErrorCode(20201, NULL);
 			}
 		}
 		if (dirM == NULL) {
@@ -818,6 +845,8 @@ class swExStruct_i: public swExStruct
 		if (leadingPathM == NULL) {
 			leadingPathM = ::strob_open(16);
 		}
+		if (errorMessagesM == NULL)
+			errorMessagesM = strar_open();
 	}
 };
 #endif
