@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2003,2004  James H. Lowe, Jr.  <jhlowe@acm.org>
+ * Copyright (C) 2003,2004,2005,2006  James H. Lowe, Jr.  <jhlowe@acm.org>
  *
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
@@ -659,7 +659,7 @@ class swObjFiles_i:  public swExStruct_i
 		xcfile->add(SW_A_source, "INFO");
 		att = xcfile->findAttribute(SW_A_source);
 		if (!att) {
-			setErrorCode(10132);
+			setErrorCode(10132, NULL);
 		} else {
 			att->vremove();
 		}
@@ -687,7 +687,7 @@ class swObjFiles_i:  public swExStruct_i
 
 		SWLIB_ASSERT(size > 0);
 		if (size <= 0) {
-			setErrorCode(10301);
+			setErrorCode(10301, NULL);
 			return;
 		}
 
@@ -705,7 +705,7 @@ class swObjFiles_i:  public swExStruct_i
 			if (::strcmp(tagvalue, "INFO") == 0) {
 				value = inext->find("size");
 				if (value == NULL) {
-					setErrorCode(10302);
+					setErrorCode(10302, NULL);
 					return;
 				}
 				::strncpy(value, asize,
@@ -774,7 +774,7 @@ class swObjFiles_i:  public swExStruct_i
 					// This is the code path for a missing source file.
 					//
 					fprintf(stderr, "swpackage: perhaps the source file is missing: %s\n", inext->find(SW_A_source));
-					setErrorCode(10503);
+					setErrorCode(10503, NULL);
 					break;
 				}
 			}
@@ -815,14 +815,30 @@ class swObjFiles_i:  public swExStruct_i
 	}
 	
 	virtual void addControlDirectoryAttribute(void) {
-		char * p;
+		char * p, *tag;
 		swDefinition * swdef = getReferer();
 
+		//
+		// Take this opportunity to make sure the tag
+		// value and control_directory is legal according to POSIX
+		//
+		tag = swdef->find(SW_A_tag);
+		if (!tag) {
+			setErrorCode(10347, NULL);
+			return;
+		}
+
+		if (swlib_check_legal_tag_value(tag)) {
+			strob_sprintf(sbufM, 0, "illegal characters is tag value: %s", tag);
+			setErrorCode(10348, strob_str(sbufM));
+		}
+
+		//
+		// FIXME check the string lengths against the POSIX limits
+		//
 		p = swdef->find(SW_A_control_directory);
 		if (p) return;
-		p = swdef->find(SW_A_tag);
-		if (!p) setErrorCode(1);
-		swdef->add(SW_A_control_directory, p);
+		swdef->add(SW_A_control_directory, tag);
 	}
 	
 	void setupAttributeFiles(void) {
@@ -1086,7 +1102,7 @@ class swObjFiles_i:  public swExStruct_i
 					// Hack, reopen the released descriptor.
 			fd = swfile->swfile_re_open_public_image_fd();
 			if (fd < 0) {
-				setErrorCode(10136);
+				setErrorCode(10136, NULL);
 				strob_close(tmp);
 				return;
 			}
@@ -1095,7 +1111,7 @@ class swObjFiles_i:  public swExStruct_i
 			if (size < 0) {
 				fprintf(stderr, "nullfd = %d   fd = %d\n",
 								nullfd, fd);
-				setErrorCode(10138);
+				setErrorCode(10138, NULL);
 				strob_close(tmp);
 				return;
 			}
@@ -1125,7 +1141,7 @@ class swObjFiles_i:  public swExStruct_i
 
 			att = xcfile->findAttribute(SW_A_source);
 			if (!att) {
-				setErrorCode(10332);
+				setErrorCode(10332, NULL);
 			} else {
 				att->vremove();
 			}
@@ -1147,7 +1163,7 @@ class swObjFiles_i:  public swExStruct_i
 						//
 						// Sanity check;
 						//
-						setErrorCode(10333);
+						setErrorCode(10333, NULL);
 					} else {
 						strncpy(value + 1,
 							strob_str(tmp),
@@ -1181,7 +1197,7 @@ class swObjFiles_i:  public swExStruct_i
 			getCreateTime(),
 			getCatalogDirModeString(),
 			getCatalogOwner(), getCatalogGroup());
-		if (ret < 0) setErrorCode(20005);
+		if (ret < 0) setErrorCode(20005, NULL);
 	}
 	
 	//
@@ -1225,7 +1241,7 @@ class swObjFiles_i:  public swExStruct_i
 				getCatalogOwner(),
 				getCatalogGroup()
 				);
-			if (ret < 0) setErrorCode(20006);
+			if (ret < 0) setErrorCode(20006, NULL);
 		}
 		return;
 	}
@@ -1317,7 +1333,7 @@ class swObjFiles_i:  public swExStruct_i
 			ret = 0;
 			if (is_duplicate == 0)
 				ret = swfile->xFormat_write_file();
-			if (ret < 0) setErrorCode(20008);
+			if (ret < 0) setErrorCode(20008, NULL);
 			swfile->swfile_re_close_public_image_fd();
 			swfile = archiveMemberList->
 				get_pointer_from_index(index++);
@@ -1515,7 +1531,7 @@ class swObjFiles_i:  public swExStruct_i
 		new_fd = swlib_open_memfd();
 		if (new_fd < 0) {
 			set_preview_fd(old_preview_fd);	
-			setErrorCode(10338);
+			setErrorCode(10338, NULL);
 			return;
 		}	
 		
@@ -1529,7 +1545,7 @@ class swObjFiles_i:  public swExStruct_i
 			strlen(s) != strlen(signame)
 		) {
 			set_preview_fd(old_preview_fd);	
-			setErrorCode(10339);
+			setErrorCode(10339, NULL);
 			return;
 		}
 	
@@ -1558,7 +1574,7 @@ class swObjFiles_i:  public swExStruct_i
 		if ((s=strstr(base, sigpath)) == NULL ||
 			strlen(s) != strlen(sigpath)
 		) {
-			setErrorCode(10340);
+			setErrorCode(10340, NULL);
 			return;
 		}
 
@@ -1569,7 +1585,7 @@ class swObjFiles_i:  public swExStruct_i
 		datafd = swfile->swfile_re_open_public_image_fd();
 		if (datafd >= 0) {
 			if (uxfio_write(datafd, base, 512) != 512) {
-				setErrorCode(10341);
+				setErrorCode(10341, NULL);
 				return;
 			}
 			swfile->swfile_re_close_public_image_fd();
@@ -1611,7 +1627,7 @@ class swObjFiles_i:  public swExStruct_i
 			swfile->xFormat_set_user_systempair(getCatalogOwner());
 			swfile->xFormat_set_group_systempair(getCatalogGroup());
 			ret = swfile->xFormat_write_file();
-			if (ret < 0) setErrorCode(20009);
+			if (ret < 0) setErrorCode(20009, NULL);
 		}
 		swfile->swfile_re_close_public_image_fd();
 		strob_close(tmp);
@@ -1666,7 +1682,7 @@ class swObjFiles_i:  public swExStruct_i
 			//
 			datafd = swattfile->swfile_open_public_image_fd();
 			if (datafd < 0) {
-				setErrorCode(10148);
+				setErrorCode(10148, NULL);
 				strob_close(tmp);
 				return -2;
 			}
@@ -1678,7 +1694,7 @@ class swObjFiles_i:  public swExStruct_i
 			if (fd < 0) {
 				fprintf(stderr, "error : open error : %s\n",
 					source);
-				setErrorCode(10445);
+				setErrorCode(10445, NULL);
 				strob_close(tmp);
 				return -3;
 			}
@@ -1688,7 +1704,7 @@ class swObjFiles_i:  public swExStruct_i
 			// (and be retained in memory).
 			//
 			if (swlib_pipe_pump(datafd, fd) < 0) {
-				setErrorCode(10448);
+				setErrorCode(10448, NULL);
 				strob_close(tmp);
 				return -4;
 			}
@@ -1710,7 +1726,7 @@ class swObjFiles_i:  public swExStruct_i
 
 			datafd = swattfile->swfile_open_public_image_fd();
 			if (datafd < 0) {
-				setErrorCode(10151);
+				setErrorCode(10151, NULL);
 				strob_close(tmp);
 				return -2;
 			}
@@ -1745,7 +1761,7 @@ class swObjFiles_i:  public swExStruct_i
 		if (swdef) {
 			if (swattfile->xFormat_apply_swdef_stats(swdef,
 						source, logical_find, (STROB*)(NULL))) {
-				setErrorCode(10449);
+				setErrorCode(10449, NULL);
 			}
 		}
 
