@@ -286,7 +286,7 @@ char * swDefinition::getPathAttribute(void)
 
 char * swDefinition::getTagAttribute(void)
 {
-	return find("tag");
+	return find(SW_A_tag);
 }
 
 swMetaData * swDefinition::findAttribute(char * keyword)
