@@ -330,11 +330,6 @@ public: // =====================================================================
 				path = "./";
 			}
 			
-			//
-			// Guard against shell-meta characters.
-			//
-			swlib_is_sh_tainted_string_fatal(path);
-
 			ret=processExplicitFile_i(path, swdef, &st, 1, 1, NULL);
 			assert(swdefFormedM);
 			swdefFormedM->set_no_stat(1);
@@ -479,14 +474,14 @@ public: // =====================================================================
 		level+=2;
 		if (strcmp(keyword, "control_file")) {
 			SWEXTDEF_DEBUG("");
-			swatt = swAttribute::make_newAttribute(parent_swdef->get_mem_fd(), "tag", keyword);
+			swatt = swAttribute::make_newAttribute(parent_swdef->get_mem_fd(), SW_A_tag, keyword);
 			if (path == NULL) {
 				SWEXTDEF_DEBUG("");
 				path = keyword;
 			}
 		} else {
 			SWEXTDEF_DEBUG("");
-			swatt = swAttribute::make_newAttribute(parent_swdef->get_mem_fd(), "tag", swlib_basename(NULL, source));
+			swatt = swAttribute::make_newAttribute(parent_swdef->get_mem_fd(), SW_A_tag, swlib_basename(NULL, source));
 			if (path == NULL) {
 				SWEXTDEF_DEBUG("");
 				path = swlib_basename(NULL, source);
