@@ -27,8 +27,7 @@
 #include "swuser_config.h"
 #include "cplob.h"
 
-
-/*------------ public API routines ------------------------- */
+/*-------- CPLOB public API routines ------------------------- */
 
 CPLOB *
 cplob_open(int nobj)
@@ -62,11 +61,12 @@ cplob_release(CPLOB * lob)
 	return p;
 }
 
-int 
+void 
 cplob_close(CPLOB * lob)
 {
         cplob_freeall (lob);
-	return cplob_shallow_close(lob);
+	free(lob->list);
+	free(lob);
 }
 
 int 
@@ -86,7 +86,6 @@ cplob_shallow_reset(CPLOB * lob)
 	}
 }
 
-o__inline__
 char **
 cplob_get_list(CPLOB * cplob)
 {
@@ -136,15 +135,12 @@ cplob_add_nta(CPLOB * lob, char *addr)
 	cplob_additem(lob, lob->nused, NULL);
 }
 
-
-o__inline__
 void
 cplob_add(CPLOB * lob, char *addr) 
 {
 	cplob_additem(lob, lob->nused, addr);
 }
 
-
 void
 cplob_additem(CPLOB * lob, int index, char *addr)
 {
@@ -160,21 +156,18 @@ cplob_additem(CPLOB * lob, int index, char *addr)
 	return;
 }
 
-o__inline__
 void
 cplob_set_nused(CPLOB * lob, int n)
 {
 	lob->nused=n;
 }
 
-o__inline__
 int
 cplob_get_nused(CPLOB * lob)
 {
 	return lob->nused;
 }
 
-o__inline__
 char *
 cplob_val(CPLOB * lob, int index)
 {
@@ -184,50 +177,6 @@ cplob_val(CPLOB * lob, int index)
 	return *(lob->list + (index));
 }
 
-/*
-void
-cplob_insertitem(CPLOB * lob, int index, char *addr)
-{
-	if (lob->nused + 1 > lob->nlen) {
-		cplob_reopen(lob->nlen + CPLOB_NLENGTHINCR, lob);
-	}
-
-	if (index < lob->nused) {
-		memmove(lob->list + ((index + 1)), lob->list + (index),
-								lob->width);
-		memmove(lob->list + (index), &addr, lob->width);
-		(lob->nused)++;
-	} else {
-		memmove(lob->list + (index), &addr, lob->width);
-		lob->nused = index + 1;
-	}
-	return;
-}
-
-
-int
-cplob_deleteitem(CPLOB * lob, int index)
-{
-
-	if (index + 1 > lob->nused) {
-		return -1;
-	}
-
-	if (lob->nused < 1) {
-		return -2;
-	}
-
-	if (index < lob->nused && *(lob->list + (index))) {
-		swbis_free(*(lob->list + (index)));
-		*(lob->list + (index))=(char *)NULL;
-	}	
-	if (index + 1 == lob->nused) {
-		lob->nused--;
-	}
-	return 0;
-}
-*/
-
 int
 cplob_backfill_and_nullterminate (CPLOB * lob)
 {
