@@ -768,7 +768,7 @@ rpmpsf_write_product(TOPSF * topsf, int uxfio_ofd, STROB * all_filesets, int fil
 		strob_strcpy(tagstring, strob_str(rpmtagname));
 		swlib_tr(strob_str(tagstring), (int)('_'), (int)('.'));  /* '.' are not allowed in tags */
 		swlib_tr(strob_str(tagstring), (int)('_'), (int)('/'));  /* '/' are not allowed in tags */
-		if (swlib_is_clean_path(strob_str(tagstring)) != 0) {
+		if (swlib_check_clean_path(strob_str(tagstring)) != 0) {
 			/*
 			 * Fatal
 			 */
@@ -1226,7 +1226,7 @@ rpmpsf_write_file_psf(TOPSF * topsf, int arrayindex, int uxfio_ofd, char *source
 	) {
 		fprintf(stderr,"rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEFLAGS ... failed\n");
 	} else {
-		fileflag = atoi(strob_str(strb));
+		fileflag = swlib_atoi(strob_str(strb), NULL);
 	}
 	
 	ret += rpmpsf_get_rpm_filenames_tagvalue(h, arrayindex, (int *) NULL, strb);
@@ -1268,7 +1268,7 @@ rpmpsf_write_file_psf(TOPSF * topsf, int arrayindex, int uxfio_ofd, char *source
 
 
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMODES, arrayindex, (int *) NULL, strb);
-	mode = (mode_t) atoi(strob_str(strb));
+	mode = (mode_t) swlib_atoi(strob_str(strb), NULL);
 	modeval[0] = (char) get_filetype(topsf, path, mode, &link_s);
 	modeval[1] = '\0';
 	if (link_s == NULL) {
@@ -1720,7 +1720,7 @@ rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb
 					index);
 			return -1;
 		}
-		index = atoi(strob_str(strb));
+		index = swlib_atoi(strob_str(strb), NULL);
 		strob_setlen(strb, 0);
 		if (rpmpsf_get_rpmtagvalue(h, RPMTAG_DIRNAMES, index, pcount, strb)) {
 			strob_strcpy(strb, "");
