@@ -22,8 +22,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
 
-
-
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -35,7 +33,6 @@
 #include "swparse.h"
 #include "strob.h"
 
-
 int
 swdef_write_attribute(char *keyword, char *value, int level, int len, 
 					int attribute_type, int uxfio_fd)
@@ -87,37 +84,9 @@ swdef_write_keyword(char *keyword, int level,
 	return iret;
 }
 
-int 
-OLDswdef_write_keyword(char *keyword, int level, 
-			int attribute_type, int uxfio_fd)
-{
-	char sp[40];
-	int iret = 0, ret = 0;
-
-	memset(sp, 040, sizeof(sp));
-	if (level > (int)sizeof(sp)) level = sizeof(sp);
-	
-	iret = uxfio_write(uxfio_fd, sp, level);
-	if (iret < 0)
-		return -1;
-	ret += iret;
-
-	ret += uxfio_write(uxfio_fd, keyword, strlen(keyword));
-
-	if (attribute_type == SWPARSE_MD_TYPE_OBJ) {
-		strcpy(sp, "\n");
-		iret = uxfio_write(uxfio_fd, sp, strlen(sp));
-	} else {
-		strcpy(sp, " ");
-		iret = uxfio_write(uxfio_fd, sp, strlen(sp));
-	}
-	return ret += iret;
-}
-
 int 
 swdef_write_value_to_buffer(STROB * ob, char *value)
 {
-	char buf0[8];
 	char *newbuf = NULL, *s;
 	int newlen, ret = 0;
 
@@ -132,7 +101,6 @@ swdef_write_value_to_buffer(STROB * ob, char *value)
 		ret = 2;
 	} else if (strstr(value, "\\n") || 
 			strstr(value, "\n") || strpbrk(value, "#\"\\")) {
-		sprintf(buf0, "\"");
 		strob_strcat(ob, "\"");
 		ret = 1;
 		strob_strncat(ob, newbuf, newlen);
