@@ -118,6 +118,7 @@ swheader_goto_c_next_line (void * vheader, int * output_line_offset,
 	if (!keyw)
 		return NULL;
 	n = swheaderline_get_value_length(ih+(*output_line_offset));
+	if (n < 0) return NULL;
         if (type == 'A') n++; /* add the space between the value and keyword*/
 
 	/* detecting the last line requires that there be a NULL 
@@ -150,6 +151,59 @@ swheader__reset(SWHEADER * swheader)
 	*(swheader->current_offset_p_)=0;
 }
 
+static char *
+get_object(SWHEADER * swheader, SWVERID * swverid,
+			int (*f_comp)(SWVERID *, SWVERID *))
+{
+	char * next_line;
+	SWVERID *t_swverid = NULL;
+	int object_offset;
+	Swverid_Cmp_Code comparison_result;
+
+
+	if (f_comp == NULL)
+		f_comp = swverid_vtagOLD_compare;
+
+	SWHEADER_E_DEBUG("");
+
+	/*
+	 * step to first object
+ 	 */
+	next_line=swheader_get_current_line(swheader);
+	if (!next_line)
+		return NULL;
+	while ( next_line && (swheaderline_get_type(next_line)
+						!= SWPARSE_MD_TYPE_OBJ))
+		next_line=swheader_f_goto_next(swheader);
+
+	/*
+	 * Now compare current object to the object described by 'swverid'
+	 */
+	do {
+		object_offset=swheader_get_current_offset(swheader);
+		t_swverid = swverid_open(NULL, (char*)(NULL));
+		if (swheader_generate_swverid(swheader, t_swverid, next_line)) {
+			fprintf(stderr, "swheader_get_object: error returned by get_object.\n");	
+			return (char *)NULL;
+		}
+		comparison_result = (*f_comp)(swverid, t_swverid);
+		if (comparison_result==SWVERID_CMP_EQ) {
+			swverid_close(t_swverid);
+			t_swverid = NULL;
+			swheader_set_current_offset_p_value(swheader,
+								object_offset);
+			return next_line;
+		}
+		swverid_close(t_swverid);
+		t_swverid = NULL;
+	} while ((next_line = swheader_get_next_object(swheader,
+					(int)(UCHAR_MAX), (int)UCHAR_MAX)));
+	if (t_swverid) swverid_close(t_swverid);
+	swheader_set_current_offset_p_value(swheader, object_offset);
+	return (char*)NULL;
+}
+
+
 /* -------------------------------------------------------------------*/
 /* ------------------ Public Functions ------------------------------*/
 
@@ -463,20 +517,25 @@ swheader_get_next_object(SWHEADER * swheader , int relative_level_min,
 	return NULL;
 }
 
-SWVERID *
-swheader_generate_swverid(SWHEADER * swheader, char * object_line)
+int
+swheader_generate_swverid(SWHEADER * swheader, SWVERID * swverid, char * object_line)
 {
 	int len;
-	SWVERID * swverid;
 	char *next_attr, *keyw, *value, *object_keyword;
 	int object_offset=swheader_get_current_offset(swheader);
 	
-	/* make the identity object */
 	if (object_line == (char*)(NULL))
-		return (SWVERID*)(NULL);
-	object_keyword = swheaderline_get_keyword(object_line);
-	swverid = swverid_open(object_keyword, (char*)NULL);
+		return -1;
 
+	/*
+	 * Enforce requirement that we must be at the start of an object
+	 */
+	if (swheaderline_get_type(object_line) != SWPARSE_MD_TYPE_OBJ)
+		return -2;
+	
+	object_keyword = swheaderline_get_keyword(object_line);
+
+	swverid_set_namespace(swverid, object_keyword);
 	while ((next_attr = swheader_get_next_attribute(swheader))) {
 		value = swheaderline_get_value(next_attr, &len);
 		keyw = swheaderline_get_keyword(next_attr);
@@ -485,17 +544,19 @@ swheader_generate_swverid(SWHEADER * swheader, char * object_line)
 				"error in swheader_generate_swverid.\n");	
 			swheader_set_current_offset_p_value(swheader,
 						object_offset);
-			swverid_close(swverid);
-			return (SWVERID*)(NULL);
+			return -3;
 		}
 		if (swverid_add_attribute(swverid,
 				object_keyword, keyw, value) < 0) {
-			swverid_close(swverid);
-			return (SWVERID*)(NULL);
+			return -4;
 		}
 	}
+
+	/*
+	 * Restore the position in the header.
+	 */
 	swheader_set_current_offset_p_value(swheader, object_offset);
-	return swverid;
+	return 0;
 }
 
 char *
@@ -516,7 +577,7 @@ swheader_get_single_attribute_value(SWHEADER * swheader, char *keyword)
 * Deprecated 
 */
 char *
-swheader_get_attribute_single_value(SWHEADER *swheader,
+swheader_get_attribute(SWHEADER *swheader,
 					char *attribute_keyword) {
 	int multi;
 	char **list;
@@ -645,50 +706,6 @@ swheader_get_next_attribute(SWHEADER * swheader)
 	}
 }
 
-char *
-swheader_get_object(SWHEADER * swheader, SWVERID * swverid)
-{
-	char * next_line;
-	SWVERID *t_swverid = NULL;
-	int object_offset;
-	Swverid_Cmp_Code comparison_result;
-
-	SWHEADER_E_DEBUG("");
-	/* step to first object */
-	
-	next_line=swheader_get_current_line(swheader);
-	if (!next_line)
-		return NULL;
-	while (
-		next_line && 
-		(swheaderline_get_type(next_line) != SWPARSE_MD_TYPE_OBJ))
-		next_line=swheader_f_goto_next(swheader);
-
-	do {
-		object_offset=swheader_get_current_offset(swheader);
-		if ((t_swverid = swheader_generate_swverid(swheader, next_line)) ==
-							 (SWVERID*)(NULL)){
-			fprintf(stderr,
-	"swheader_get_object: error returned by swheader_generate_swverid.\n");	
-			return (char *)NULL;
-		}
-		comparison_result = swverid_compare(swverid, t_swverid);
-		if (comparison_result==SWVERID_CMP_EQ) {
-			swverid_close(t_swverid);
-			t_swverid = NULL;
-			swheader_set_current_offset_p_value(swheader,
-								object_offset);
-			return next_line;
-		}
-		swverid_close(t_swverid);
-		t_swverid = NULL;
-	} while ((next_line = swheader_get_next_object(swheader,
-					(int)(UCHAR_MAX), (int)UCHAR_MAX)));
-	if (t_swverid) swverid_close(t_swverid);
-	swheader_set_current_offset_p_value(swheader, object_offset);
-	return (char*)NULL;
-}
-
 char *
 swheader_get_object_by_tag(SWHEADER * swheader, 
 					char *object_keyword,
@@ -700,7 +717,7 @@ swheader_get_object_by_tag(SWHEADER * swheader,
 	SWHEADER_E_DEBUG("");
 	swverid_set_tag(swverid, "tag", idtag);
 	swverid_set_comparison_code(swverid, SWVERID_CMP_EQ);
-	ret = swheader_get_object(swheader, swverid);
+	ret = get_object(swheader, swverid, swverid_vtagOLD_compare);
 	swverid_close(swverid);
 	return ret;
 }
@@ -883,10 +900,10 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 			did_mtime = 1;
 			(file_hdr->usage_maskM) |= TARU_UM_MTIME;
 		} else if (strcmp(keyword, "major") == 0) {
-			file_hdr->c_dev_maj = atoi(value);	
+			file_hdr->c_dev_maj = swlib_atoi(value, NULL);	
 			did_major = 1;
 		} else if (strcmp(keyword, "minor") == 0) {
-			file_hdr->c_dev_min = atoi(value);	
+			file_hdr->c_dev_min = swlib_atoi(value, NULL);	
 			did_minor = 1;
 		} else if (strcmp(keyword, "type") == 0) {
 			info_filetype = (int)(*value);	
