@@ -134,8 +134,8 @@ swheaderline_get_keyword(char *output_line)
 		/* good */
 	} else {
 		/* bad */
-		fprintf(stderr,
-			"internal error in swheaderline_get_keyword\n");
+		fprintf(stderr, "internal error in swheaderline_get_keyword\n");
+		return NULL;
 	}
 
 	t+=3;
