@@ -2,7 +2,7 @@
  */
 
 /*
-  Copyright (C) 2004,2005 Jim Lowe
+  Copyright (C) 2004, 2005, 2006 Jim Lowe
   All Rights Reserved.
   
   COPYING TERMS AND CONDITIONS:
@@ -19,6 +19,8 @@
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 
+#define FILENEEDDEBUG 1 /* controls the E_DEBUG macros */
+#undef FILENEEDDEBUG
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -169,13 +171,13 @@ print_task_group(SWICOL * swicol, STROB * group_script,
 
 static
 int
-print_task_script(SWICOL * swicol, STROB * command, int size, char * dir, char * task_script, char * task_desc)
+print_task_script(SWICOL * swicol, STROB * command, unsigned long int size, char * dir, char * task_script, char * task_desc)
 {
 	char * verbosestring;
 	char * tonullstring;
 	STROB * enddesc = strob_open(32);
 
-	int blocks = size / 512;
+	int blocks = (int)(size / 512);
 	if (size % 512) {
 		/*
 		 * size must be a whole number of 512 blocks.
@@ -189,7 +191,6 @@ print_task_script(SWICOL * swicol, STROB * command, int size, char * dir, char *
 	 */
 
 	if (swlib_is_ascii_noaccept(dir, SWBIS_TAINTED_CHARS "\a\b\n\r\t \v\\", 1)) {
-		/* fprintf(stderr, "JLaa here 1 [%s]\n", dir); */
 		return 1;
 	}
 
@@ -358,7 +359,7 @@ swicol_rpsh_task_send_group_script(SWICOL * swicol, int fd,
 
 int
 swicol_rpsh_task_send_script(SWICOL * swicol, int fd,
-		int data_size, char * dir, char * script, char * desc)
+		unsigned long int data_size, char * dir, char * script, char * desc)
 {
 	int ret;
 	int eret;
@@ -465,7 +466,7 @@ swicol_rpsh_task_wait(SWICOL * swicol, STROB * retbuf,
 		 * time limit exceeded.
 		 */
 		retval = 2;
-		swlib_doif_writef(swicol->verbose_levelM, 1, swicol->logspecM,
+		swutil_doif_writef(swicol->verbose_levelM, 1, swicol->logspecM,
 				STDERR_FILENO,
 				"SW_RESOURCE_ERROR: time limit of %d seconds exceeded\n",
 							timelimit);
@@ -490,6 +491,8 @@ swicol_rpsh_get_event_message(SWICOL * swicol, int event_value,
 
 	strob_sprintf(tmp, 0, "%d:", event_value);
 
+	E_DEBUG2("event value=[%s]", strob_str(tmp));
+
 	s = strar_get(event_list, ix++);
 	while(s) {
 		if (strstr(s, strob_str(tmp))) {
@@ -511,6 +514,7 @@ swicol_rpsh_get_event_status(SWICOL * swicol, char * msg,
 		int event_value, int first_current_event, int * p_index)
 {
 	int retval;
+	int atoi_ret;
 
 	if (!msg)
 		msg = swicol_rpsh_get_event_message(swicol, event_value, first_current_event, p_index);
@@ -520,7 +524,10 @@ swicol_rpsh_get_event_status(SWICOL * swicol, char * msg,
 	 */
 	if (!msg) return -1;
 	if (isdigit((int)(*msg))) {
-		retval = atoi(msg);
+		retval = swlib_atoi(msg, &atoi_ret);
+		if (atoi_ret) {
+			retval = -127;
+		}
 	} else {
 		fprintf(stderr,
 			"%s: event %d does not return a status\n",
@@ -546,6 +553,8 @@ swicol_rpsh_task_expect(SWICOL * swicol, int event_fd, int timelimit)
 	 */
 	ret = swicol_rpsh_task_wait(swicol, buf, event_fd, timelimit);
 	retval = ret;
+	
+	E_DEBUG2("expect buffer=[%s]", strob_str(buf));
 
 	/*
 	 * Assert a user expectation for a single event.
@@ -562,8 +571,9 @@ swicol_rpsh_task_expect(SWICOL * swicol, int event_fd, int timelimit)
 			fprintf(stderr, "%s: Event error: SWI_TASK_END event has invalid status. [%s]\n",
 				swlib_utilname_get(),  strob_str(buf));
 			retval = -1;
+		} else {
+			retval = swlib_atoi(ev, NULL);
 		}
-		retval = atoi(ev);
 	}
 
 	/* fprintf(stderr, "start\n%s\nend\n", strob_str(buf)); */
@@ -787,7 +797,7 @@ swicol_NOT_USED_get_event_status(SWICOL * swicol, int event_value, int first_cur
 		/*
 		 * convert the status
 		 */
-		ret = atoi(v);
+		ret = swlib_atoi(v, NULL);
 	}
 
 	strob_close(tmp);
