@@ -93,7 +93,7 @@ typedef struct {
 
 SWICOL * swicol_create(void);
 void swicol_delete(SWICOL * swicol);
-int swicol_rpsh_task_send_script(SWICOL * swicol, int fd, int data_size, char * dir, char * script, char * desc);
+int swicol_rpsh_task_send_script(SWICOL * swicol, int fd, unsigned long int data_size, char * dir, char * script, char * desc);
 int swicol_rpsh_task_wait(SWICOL * swicol, STROB * buf, int fd, int timelimit);
 int swicol_rpsh_task_expect(SWICOL * swicol, int event_fd, int timelimit);
 int swicol_rpsh_get_event_status(SWICOL * swicol, char * msg, int event_value, int first, int *found_at);
