@@ -39,6 +39,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include "misc-fnmatch.h"
 #include "taru.h"
 #include "uxfio.h"
 #include "strob.h"
@@ -49,6 +50,7 @@
 #include "md5.h"
 #include "ugetopt_help.h"
 #include "atomicio.h"
+#include "swutillib.h"
 #include "swutilname.h"
 
 static int verbose_levelG;
@@ -122,7 +124,6 @@ process_all_escapes(char * src)
 	}
 }
 
-static
 int
 doif_writeap(int fd, STROB * buffer, char * format, va_list * pap)
 {
@@ -152,29 +153,6 @@ squash_trailing_char(char *path, char ch)
 	}
 }
 
-static
-int
-printlogline(STROB * buf, char * sptr)
-{
-	time_t tm;
-	char result[64];
-	char * s;
-	
-	time(&tm);
-	ctime_r(&tm, result);
-	s = result;
-	s = strchr(result, ' ');
-	if (s) {
-		s++; 
-	} else {
-		s = result;
-	}
-	swlib_squash_trailing_vnewline(result);
-	strob_sprintf(buf, 0, "%s [%d] %s",
-		s, (int)getpid(), sptr);
-	return 0;
-}
-
 static
 int
 nano_nanosleep(long nsec)
@@ -243,11 +221,33 @@ swlib_atoi(const char *nptr, int * result)
 		(endptr == nptr && ret == 0) ||
 		((ret == LONG_MIN || ret == LONG_MAX) && errno == ERANGE)
 	) {
-		if (result) *result = 1;
+		if (result) {
+			*result = 1;
+		}
+		fprintf(stderr, "%s: strtol error when converting [%s]\n", swlib_utilname_get(), nptr);
 	}
 	return (int)ret;
 }
 
+unsigned long int
+swlib_atoul(const char *nptr, int * result)
+{
+	unsigned long int ret;
+	char * endptr;
+	ret = strtoul(nptr, &endptr, 10);
+
+	if (result) *result = 0;
+	if (
+		(endptr == nptr && ret == 0) ||
+		((ret == ULONG_MAX) && errno == ERANGE)
+	) {
+		if (result) {
+			*result = 1;
+		}
+		fprintf(stderr, "%s: strtoul error when converting [%s]\n", swlib_utilname_get(), nptr);
+	}
+	return ret;
+}
 
 unsigned long int **
 swlib_pump_get_ppstatbytes(void)
@@ -319,14 +319,6 @@ swlib_pump_amount7(int ofd, int uxfio_ifd,
 	return (amount - am);
 }
 
-/*
-void
-swlib_nanosleep(struct timespec * io_req)
-{
-	nanosleep(io_req, NULL);
-}
-*/
-
 struct timespec * swlib_get_io_req(void)
 {
 	return io_req;
@@ -360,20 +352,6 @@ swlib_test_verbose(int verbose_level, int swbis_event,
 	}
 }
 
-int
-swlib_writelogline(int logfd, char * sptr)
-{
-	int ret;
-	STROB * buf = strob_open(64);
-	printlogline(buf, sptr);
-	ret = write(logfd, strob_str(buf), strob_strlen(buf));
-	if (ret != (int)strob_strlen(buf)) {
-		SWLIB_EXCEPTION("error writing logfile");
-	}
-	strob_close(buf);
-	return ret;
-}
-
 int
 swlib_get_verbose_level(void)
 {
@@ -536,7 +514,7 @@ swlib_tr(char * src, int to, int from)
 }
 
 int
-swlib_is_safe_path(char * s)
+swlib_check_safe_path(char * s)
 {
 	if (!s) return 1;
 	if (!strlen(s)) return 5;
@@ -546,7 +524,7 @@ swlib_is_safe_path(char * s)
 }
 
 int
-swlib_is_clean_path(char * s)
+swlib_check_clean_path(char * s)
 {
 	if (!s) return 1;
 	if (!strlen(s)) return 2;
@@ -558,20 +536,26 @@ swlib_is_clean_path(char * s)
 }
 
 int
-swlib_is_clean_absolute_path(char * s)
+swlib_check_clean_absolute_path(char * s)
 {
 	if (!s) return 1;
 	if (!strlen(s)) return 2;
 	if (*s != '/') return 3;
-	return swlib_is_clean_path(s);
+	return swlib_check_clean_path(s);
 }
 
 int
-swlib_is_clean_relative_path(char * s)
+swlib_check_clean_relative_path(char * s)
 {
 	if (!s) return 1;
 	if (*s == '/') return 2;
-	return swlib_is_clean_path(s);
+	return swlib_check_clean_path(s);
+}
+
+int
+swlib_check_legal_tag_value(char * s) {
+	if (!s) return 0; /* Ok */
+	return strpbrk(s, ":.,") ? 1 : 0;
 }
 
 int
@@ -1309,92 +1293,6 @@ swlib_writef(int fd, STROB * buffer, char * format, ...)
 	return newret;
 }
 
-int
-swlib_do_log_is_true(struct sw_logspec * logspec, int verbose_level, int write_at_level)
-{
-	if (
-		(
-			logspec->logfdM == 1 && 
-			(write_at_level < SWC_VERBOSE_6)
-			/*
-				Level 6 is the level where the file list
-				appears. It is excluded (per spec) for
-				loglevel=1
-			*/
-			
-		) ||
-		(	logspec->logfdM == 2 &&
-			(write_at_level < SWC_VERBOSE_7)
-		) ||
-		(	logspec->logfdM == 2 &&
-			(verbose_level > SWC_VERBOSE_7)
-		) 
-	) {
-		return 1;
-	} else {
-		return 0;
-	}	
-}
-
-int
-swlib_doif_writef(int verbose_level, int write_at_level, 
-			struct sw_logspec * logspec, int fd, char * format, ...)
-{
-	STROB * buffer;
-	int newret;
-	va_list ap;
-	int level;
-
-	buffer = strob_open(100);
-	va_start(ap, format);
-
-	level = verbose_level;
-	if (write_at_level >= 0 && level < write_at_level) {
-		;
-		newret = 0;
-	} else {
-		strob_strcpy(buffer, "");
-		if (write_at_level >= SWC_VERBOSE_7 ) {
-			strob_strcpy(buffer, "debug> ");
-			strob_sprintf(buffer, 1, "%s", swlib_utilname_get());
-			strob_sprintf(buffer, 1, "[%d]: ", (int)getpid());
-		} else {
-			strob_sprintf(buffer, 1, "%s: ", swlib_utilname_get());
-		}
-		newret = doif_writeap(fd, buffer, format, &ap);
-	}
-
-	if (logspec && logspec->logfdM > 0) {
-		if (swlib_do_log_is_true(logspec, verbose_level, write_at_level)) {
-			/*
-			* The only lines logged here are lines that
-			* are written to STDERR_FILENO.  If fd != STDERR_FILENO
-			* then it is assumed the line will be logged by the 
-			* logger process forked by swc_fork_logger.
-			*/
-			if (fd == STDERR_FILENO || fd == STDOUT_FILENO || fd < 0) {
-				STROB * logbuf = strob_open(100);
-				strob_strcpy(buffer, "");
-				if (write_at_level >= SWC_VERBOSE_7) {
-					strob_strcpy(buffer, "debug> ");
-					strob_sprintf(buffer, 1, "%s", swlib_utilname_get());
-					strob_sprintf(buffer, 1, "[%d]: ", (int)getpid());
-				} else {
-					strob_sprintf(buffer, 1, "%s: ", swlib_utilname_get());
-				}
-				printlogline(logbuf, strob_str(buffer));
-				newret = doif_writeap(logspec->logfdM, logbuf, format, &ap);
-				strob_close(logbuf);
-			}
-		} else {
-			newret = 0;
-		}
-	}
-	va_end(ap);
-	strob_close(buffer);
-	return newret;
-}
-
 /*
 *     swlib_write_catalog_stream
 *  write out the catalog half of the package.
@@ -1582,12 +1480,12 @@ swlib_kill_all_pids(pid_t * pid, int num, int signo, int verbose_level)
 	for(i=0; i<num; i++) {
 		if (pid[i] > 0) {
 			swlib_doif_writef(verbose_level,  SWC_VERBOSE_SWIDB,
-				(struct sw_logspec *)(NULL), STDERR_FILENO,
+				/* (struct sw_logspec *) */(NULL), STDERR_FILENO,
 				"swlib_kill_all_pids: kill[%d] signo=%d\n",
 							(int)pid[i], signo);
 			if (kill(pid[i], signo) < 0) {
 				swlib_doif_writef(verbose_level,  SWC_VERBOSE_SWIDB,
-					(struct sw_logspec *)(NULL), STDERR_FILENO,
+					/* (struct sw_logspec *)*/ (NULL), STDERR_FILENO,
 					"kill[%d] signo=%d : error : %s\n",
 						(int)pid[i],
 						signo, strerror(errno));
@@ -1624,7 +1522,8 @@ swlib_wait_on_all_pids(pid_t * pid, int num, int * status,
 	if (num == 0) return 0;
 	while (!done) {
 		done = 1;
-		if (!got_one) usleep(250000);
+		usleep(100000);  /* Sleep 1/10th second, this greatly */
+				 /* improves performance on Cygwin    */
 		for(i=0; i<num; i++) {
 			if (pid[i] > 0) {
 				wret = waitpid(pid[i], &status[i], flags);
@@ -1969,3 +1868,34 @@ swlib_add_trailing_slash(STROB *path)
 	if( *(p + strlen(p) -1) != '/')
 		strob_strcat(path,"/");
 }
+
+int
+swlib_altfnmatch(char * s1, char * s2)
+{
+	STROB * tmp1;
+	STROB * tmp2;
+	char * t1;
+	char * t2;
+
+	tmp1 = strob_open(16);
+	tmp2 = strob_open(16);
+	t1 = strob_strtok(tmp1, s1, "|\n\r");
+	while(t1) {
+		t2 = strob_strtok(tmp2, s2, "|\n\r");
+		while(t2) {
+			if (fnmatch(t1, t2, 0) != FNM_NOMATCH) {
+				/*
+				 * match
+				 */
+				strob_close(tmp1);
+				strob_close(tmp2);
+				return 0;
+			}	
+			t2 = strob_strtok(tmp2, NULL, "|\n\r");
+		}
+		t1 = strob_strtok(tmp1, NULL, "|\n\r");
+	}
+	strob_close(tmp1);
+	strob_close(tmp2);
+	return 1;
+}
