@@ -10,6 +10,7 @@
 #define SWLIB_H_02a
 
 #include "swuser_assert_config.h"
+#include "swprog_versions.h"
 #include "sw.h"
 
 #define SWLIB_PIPE_BUF 512
@@ -17,16 +18,13 @@
 #define swio_read(a, b, c) 	atomicio(read, a, b, c)
 #define swio_write(a, b, c) 	atomicio(write, a, b, c)
 
-struct sw_logspec {
-	int loglevelM;
-	int logfdM;
-};
-
 /* FIXME
 #ifndef __FUNCTION__
 #define __FUNCTION__ "unknown"
 #endif
 */
+#define SWBIS_PROGS_USER_ERROR 			20000		/* Error code >= are cockpit errors */
+#define SWBIS_PROGS_IMPLEMENTATION_ERROR 	10000		/* Error code >= are implementation errors */
 
 #define SWBIS_DEBUG_PRINT() fprintf(stderr, \
 		 "%s: %s:%d\n", \
@@ -38,7 +36,9 @@ struct sw_logspec {
 
 #define TARRECORDSIZE		512
 
-#define SWBIS_INTERNAL_ASSERT(arg, status)  swlib_swprog_assert(arg, status, "", SWPROG_VERSION, (char*)__FILE__, __LINE__, (char*)__FUNCTION__);
+#define SWBIS_INTERNAL_ASSERT(code, status)  swlib_swprog_assert(code, status, "", SWBIS_RELEASE, (char*)__FILE__, __LINE__, (char*)__FUNCTION__)
+
+#define SWBIS_IMPL_ERROR_DIE(status)  swlib_swprog_assert(SWBIS_PROGS_IMPLEMENTATION_ERROR, status, "Impl fatal internal error", SWBIS_RELEASE, (char*)__FILE__, __LINE__, (char*)__FUNCTION__)
 
 #define SWC_VERBOSE_0	0
 #define SWC_VERBOSE_1	1
@@ -98,8 +98,6 @@ struct sw_logspec {
 #define SWBN_SIGNATURE	"signature"
 #define SWBN_SIG_HEADER	"sig_header"
 
-#define SWBIS_PROGS_USER_ERROR 			20000		/* Error code >= are cockpit errors */
-#define SWBIS_PROGS_IMPLEMENTATION_ERROR 	10000		/* Error code >= are implementation errors */
 
 #define SWBIS_PROGS_LAYOUT_VERSION 		"1.0"
 
@@ -118,8 +116,11 @@ struct sw_logspec {
 #define SWBIS_SC_OPEN_MAX	24	/* Max No. of open fd's if sysconf can't tell us */
 #define SWBIS_MIN_FD_AVAIL	16	/* Minimum number of open fd to operate */
 
+#include "strob.h"
+#include "vplob.h"
 #include "xformat.h"
 #include "shcmd.h"
+/* #include "swutillib.h" */
 #include	<termios.h>
 #include	<sys/ioctl.h>	/* 44BSD requires this too */
 
@@ -159,7 +160,6 @@ int 		swlib_resolve_path(char * ppath, int * depth, STROB * resolved_path);
 int 		swlib_parse_args(int * argc, char *** argv, char * cmd);
 int		swlib_is_escapable(char);
 int		swlib_writef(int fd, STROB * buffer, char * format, ...);
-int 		swlib_doif_writef(int level, int at_level, struct sw_logspec *, int fd, char * format, ...);
 int		swlib_cat_line(STROB * line, int uxfio_fd);
 int 		swlib_write_OLDcatalog_stream(XFORMAT * package, int ofd);
 int 		swlib_write_OLDstorage_stream(XFORMAT * package, int ofd);
@@ -174,6 +174,7 @@ void 		swlib_assertion_fatal(int assertion_result, char * reason, char * file, i
 void		swlib_swprog_assert(int assertion_result, int status, char * version, char * reason, char * file, int line, char * function);
 int 		swlib_write_signing_files(XFORMAT * package, int ofd, int which_file /* 0=catalog  1=storage */, int do_adjunct_md5);
 int		swlib_atoi(const char *nptr, int * result);
+unsigned long int swlib_atoul(const char *nptr, int * result);
 int 		swlib_unix_dircat(STROB * dest, char * dirname);
 int 		swlib_dir_compare(char * s1, char * s2, int compare_flag /* See SWC_FC_* */);
 int		swlib_basename_compare(char * s1, char * s2);
@@ -210,11 +211,9 @@ int 	swlib_get_verbose_level(void);
 void 	swlib_set_verbose_level(int n);
 size_t  swlib__strlcpy(char * dst, const char * src, size_t siz);
 int 	swlib_pad_amount(int fd, int amount);
-int 	swlib_writelogline(int logfd, char * sptr);
 int 	swlib_tr(char * src, int to, int from);
 int 	swlib_process_hex_escapes(char * s1);
 int 	swlib_compare_8859(char * s1, char * s2);
-int 	swlib_do_log_is_true(struct sw_logspec * logspec, int verbose_level, int write_at_level);
 int 	swlib_test_verbose(int verbose_level, int swbis_event,
 		int is_swi_event, int event_status, int is_posix_event);
 int 	swlib_drop_root_privilege(void);
@@ -225,11 +224,14 @@ unsigned long int ** swlib_pump_get_ppstatbytes(void);
 int 	swlib_pump_amount6(int ofd, int uxfio_ifd, int amount, int adjunct_ofd);
 int 	swlib_vrelpath_compare(char * s1, char * s2, char * cwd);
 void 	swlib_add_trailing_slash(STROB *path);
-int 	swlib_is_clean_relative_path(char * s);
-int 	swlib_is_clean_path(char * s);
-int 	swlib_is_clean_absolute_path(char * s);
-int 	swlib_is_safe_path(char * s);
+int 	swlib_check_clean_relative_path(char * s);
+int 	swlib_check_clean_path(char * s);
+int 	swlib_check_clean_absolute_path(char * s);
+int 	swlib_check_safe_path(char * s);
 void swlib_internal_error(char * reason, char * file, int line, char * function);
 int swlib_expand_escape(char **pa, int *newlen, char *src);
+int swlib_rpmvercmp(const char * a, const char * b);
+int swlib_check_legal_tag_value(char * s);
+int swlib_altfnmatch(char * s1, char * s2);
 
 #endif
