@@ -16,9 +16,9 @@
 #include "strar.h"
 
 #define SWPATH_PARSE_CA		22
-#define SWPATH_CTYPE_DIR	-1
-#define SWPATH_CTYPE_CAT	1
-#define SWPATH_CTYPE_STORE	0
+#define SWPATH_CTYPE_DIR	-1  /* Leading dir */
+#define SWPATH_CTYPE_CAT	1   /* catalog section */
+#define SWPATH_CTYPE_STORE	0   /* storage section */
 
 typedef struct 
 {
@@ -107,7 +107,6 @@ typedef struct
      char * swpath_form_catalog_path (SWPATH * swpath,  STROB * buf );
      char * swpath_form_storage_path (SWPATH * swpath,  STROB * buf );
      int swpath_parse_path (SWPATH * swpath, char * name);
-     int swpath_lookup_name (SWPATH * swpath, char * name);
      int swpath_is_catalog (SWPATH * swpath, char * name);
      void swpath_set_is_catalog (SWPATH * swpath, int n);
      int swpath_get_is_catalog (SWPATH * swpath);
