@@ -1085,6 +1085,7 @@ swvarfs_i_make_link(struct new_cpio_header * file_hdr,
 	SWVARFS_E_DEBUG("ENTERING"); 
 	link->nameFC = swlib_strdup(ahsStaticGetTarFilename(file_hdr));
 	swlib_slashclean(link->nameFC);
+	swlib_process_hex_escapes(link->nameFC);  /* Collapse Hex sequences into single non-ascii octet */
 	SWVARFS_E_DEBUG3("link made name=[%s] header_offset = [%d]", link->nameFC, header_offset); 
 	SWVARFS_E_DEBUG3("link made name=[%s]   data_offset = [%d]", link->nameFC, data_offset); 
 	link->header_offsetFC = header_offset;
@@ -1219,21 +1220,31 @@ swvarfs_i_readin_filechain(SWVARFS * swvarfs, char * name)
 
 static
 struct fileChain * 
-swvarfs_i_search_filechain(SWVARFS * swvarfs, char * name,
+swvarfs_i_search_filechain(SWVARFS * swvarfs, char * name_p,
 						int * scope_rejection)
 {
 	int did_drop = 0;
 	int did_omit_lslash = 0;
+	char * name;
 	char * p;
 	struct fileChain *last=swvarfs->headM;
 
+	name = name_p;
+	if (!name) return NULL;
+	strob_strcpy(swvarfs->tmpM, name);
+	name = strob_str(swvarfs->tmpM);
+	swlib_process_hex_escapes(name);
 
 	SWVARFS_E_DEBUG2("ENTERING [%s]", name); 
 	*scope_rejection = 0;
-	if (!name) return NULL;
 	
 	while(last) {
 		p = last->nameFC;
+		
+		/*
+		 * FIXME: name must have ascii hex sequence converted to non-ascii chars
+		 */
+
 		if (strncmp(p, "./", 2) == 0) {
 			p += 2;
 		}
@@ -1465,11 +1476,13 @@ swvarfs_i_u_open_archive_bh(SWVARFS * swvarfs,
 	SWVARFS_E_DEBUG2("ENTERING [%p]", file_hdr); 
 	if (ud_find_fd(swvarfs, -1) < 0) {
 		fprintf(stderr, "too many open swvarfs:u_fd descriptors.\n");
+		SWVARFS_E_DEBUG("return -4");
 		return -4;
 	}
 
 	fd = uxfio_opendup(swvarfs->fdM, UXFIO_BUFTYPE_NOBUF);
 	if (fd < 0) {
+		SWVARFS_E_DEBUG("return -5");
 		return -5;
 	}
 	
@@ -1512,6 +1525,7 @@ swvarfs_i_u_open_archive_bh(SWVARFS * swvarfs,
 	swvarfs->u_fd_setM[u_index].u_fdM = fd;
 
 	SWVARFS_E_DEBUG("LEAVING");
+	SWVARFS_E_DEBUG2("return at last with fd=%d", fd);
 	return fd;
 }
 
