@@ -50,6 +50,8 @@
 #include "swlex_supp.h"
 #include "swparser_global.h"
 #include "swutilname.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 static void usage (char * progname, FILE*);
 
