@@ -20,6 +20,8 @@
 #include "rpmpsf.h"
 #include "swlib.h"
 #include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 int
 main(int argc, char **argv)
