@@ -14,6 +14,8 @@
 #include "taru.h"
 #include "swlib.h"
 #include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 static
 void
