@@ -1,20 +1,20 @@
 /* swi.c -- Posix package decoding. 
 
-   Copyright (C) 2004,2005 Jim Lowe
-   All Rights Reserved.
+  Copyright (C) 2004,2005,2006 Jim Lowe
+  All Rights Reserved.
   
-   COPYING TERMS AND CONDITIONS:
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+  COPYING TERMS AND CONDITIONS:
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2, or (at your option)
+  any later version.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include "swuser_config.h"
 #include <stdio.h>
@@ -86,7 +86,7 @@ find_object_by_swsel(void * parent, char * swsel)
 
 	package = (SWI_PACKAGE *)(parent);
 	for(i=0; i<SWI_MAX_OBJ; i++) {
-		object = (SWI_BASE*)(package->swi_coM[i]);
+		object = (SWI_BASE*)(&(package->swi_coM[i]->baseM));
 		if (object) {
 			/*
 			 * FIXME, crudely handle version ids by ignoring them
@@ -183,8 +183,8 @@ swi_xfile_add_control_script(SWI * swi, SWI_XFILE * xfile, char * name,
 	/* offset = swi->xformatM->swvarfsM->current_header_offsetM;*/
 	s = swi_xfile_construct_file_member(xfile, name, fd,
 					swi->xformatM->swvarfsM);
-	sc->tagM = strdup(tag);
-	swi_com_check_clean_relative_path(sc->tagM);
+	sc->baseM.tagM = strdup(tag);
+	swi_com_check_clean_relative_path(sc->baseM.tagM);
 	sc->afileM = s;
 	swi_add_script(xfile->swi_scM, sc);
 	return;
@@ -204,27 +204,48 @@ swi_xfile_add_file_member(SWI * swi, SWI_XFILE * xfile, char * name, int fd)
 int
 swi_get_distribution_attributes(SWI * swi, SWHEADER * swheader)
 {
+	char * value;
+	char * obj;
+	
+	swi_com_header_manifold_reset(swheader);
+	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "*" );
+	if (!obj) {
+		return -1;
+	}
+	value = swheader_get_single_attribute_value(swheader, SW_A_dfiles);
+	if (value)
+		swi->swi_pkgM->dfiles_attributeM = strdup(value);
+	else
+		swi->swi_pkgM->dfiles_attributeM = strdup(SW_A_dfiles);
+
+	value = swheader_get_single_attribute_value(swheader, SW_A_pfiles);
+	if (value)
+		swi->swi_pkgM->pfiles_attributeM = strdup(value);
+	else
+		swi->swi_pkgM->pfiles_attributeM = strdup(SW_A_pfiles);
+
+	return 0;
+
+
+	/*
 	char * obj;
 	char * line;
 	char * value;
-		
+	
 	swi_com_header_manifold_reset(swheader);
-	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "" );
-	line = swheader_get_attribute_single_value(swheader, SW_A_dfiles);
+	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "*" );
+	line = swheader_get_attribute(swheader, SW_A_dfiles);
 	if (line) {
 		value = swheaderline_get_value(line, (int*)NULL);
 		swi_com_assert_pointer((void*)value, __FILE__, __LINE__);
 		swi->swi_pkgM->dfiles_attributeM = strdup(value);
 	} else {
-		/*
-		 * FIXME? This should be an error.
-		 */
 		swi->swi_pkgM->dfiles_attributeM = strdup(SW_A_dfiles);
 	}
 	
 	swi_com_header_manifold_reset(swheader);
-	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "" );
-	line = swheader_get_attribute_single_value(swheader, SW_A_pfiles);
+	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "*" );
+	line = swheader_get_attribute(swheader, SW_A_pfiles);
 	if (line) {
 		value = swheaderline_get_value(line, (int*)NULL);
 		swi_com_assert_pointer((void*)value, __FILE__, __LINE__);
@@ -233,6 +254,7 @@ swi_get_distribution_attributes(SWI * swi, SWHEADER * swheader)
 		swi->swi_pkgM->pfiles_attributeM = strdup(SW_A_pfiles);
 	}
 	return 0;
+	*/
 }
 
 void 
@@ -258,7 +280,7 @@ swi_package_delete(SWI_PACKAGE * s)
 		 free(s->installed_software_catalogM);
 	}
 	if (s->dfilesM) swi_xfile_delete(s->dfilesM);
-	if (s->headerM) swheader_close(s->headerM);
+	if (s->baseM.global_headerM) swheader_close(s->baseM.global_headerM);
 	if (s->swdef_fdM > 0) uxfio_close(s->swdef_fdM);
 	s->swdef_fdM = -1;
 	swi_scripts_delete(s->swi_scM);
@@ -277,10 +299,10 @@ swi_package_create(void)
 	SWSWI_E_DEBUG("");
 	swi_com_assert_pointer((void*)s, __FILE__, __LINE__);
 	swiInitListOfObjects((void**)(s->swi_coM));
-	swi_base_init((SWI_BASE*)(s), SWI_I_TYPE_PACKAGE, NULL, NULL);
+	swi_vbase_init(s, SWI_I_TYPE_PACKAGE, NULL, NULL);
 	s->swi_scM = swi_scripts_create();
 	s->exlistM = cplob_open(1);
-	s->headerM = NULL;
+	s->baseM.global_headerM = NULL;
 	s->swdef_fdM = -1;
 	s->current_productM = NULL;
 	s->dfilesM = NULL;
@@ -326,6 +348,7 @@ SWI * swi_create(void)
 	swi->exported_catalog_prefixM = NULL;
 	swi->verboseM = 0;
 	swi->debug_eventsM = 0;
+	swi->version_idM = swverid_open("HOST", NULL);
 	return swi;
 }
 
@@ -333,14 +356,12 @@ void
 swi_product_delete(SWI_PRODUCT * s)
 {
 	int i;
-	if (s->tagM) free(s->tagM);
+	if (s->baseM.tagM) free(s->baseM.tagM);
 	if (s->package_pathM) free(s->package_pathM);
 	if (s->control_dirM) free(s->control_dirM);
 
 	if (s->filesetsM) strar_close(s->filesetsM);
 
-	/* if (s->swi_scM) swi_scripts_delete(s->swi_scM); */
-
 	if (s->pfilesM) swi_xfile_delete(s->pfilesM);
 	
 	for(i=0; i<SWI_MAX_OBJ; i++) {
@@ -366,7 +387,7 @@ swi_product_create(SWHEADER * global_index_header, SWPATH_EX * current)
                 }
         #endif
 
-	swi_base_init((SWI_BASE*)(s), SWI_I_TYPE_PROD, global_index_header, current);
+	swi_vbase_init(s, SWI_I_TYPE_PROD, global_index_header, current);
 
 	s->package_pathM = (char*)NULL;
 	s->control_dirM = (char*)NULL;
@@ -420,7 +441,7 @@ swi_store_file(SWI * swi, char * name, SWI_XFILE * current_xfile) {
 int
 swi_expand_shared_file_control_sripts(SWI * swi, SWI_XFILE * xfile)
 {
-	SWHEADER * swheader = xfile->headerM;
+	SWHEADER * swheader = xfile->info_headerM;
 	SWI_CONTROL_SCRIPT * script;
 	SWI_CONTROL_SCRIPT * new_script;
 	SWI_FILE_MEMBER * afile;
@@ -440,9 +461,9 @@ swi_expand_shared_file_control_sripts(SWI * swi, SWI_XFILE * xfile)
 		swheader_goto_next_line((void *)swheader, 
 			swheader_get_current_offset_p(swheader), 
 				SWHEADER_PEEK_NEXT);
-		path_attr = swheader_get_attribute_single_value(swheader,
+		path_attr = swheader_get_attribute(swheader,
 			SW_A_path);
-		tag_attr = swheader_get_attribute_single_value(swheader,
+		tag_attr = swheader_get_attribute(swheader,
 			SW_A_tag);
 
 		/*
@@ -482,8 +503,8 @@ swi_expand_shared_file_control_sripts(SWI * swi, SWI_XFILE * xfile)
 				SWLIB_ASSERT(afile != NULL);
 					
 				new_script = swi_control_script_create();
-				new_script->tagM = strdup(tag_value);
-				swi_com_check_clean_relative_path(new_script->tagM);
+				new_script->baseM.tagM = strdup(tag_value);
+				swi_com_check_clean_relative_path(new_script->baseM.tagM);
 				new_script->afileM = afile;
 				(afile->refcountM)++;
 				swi_add_script(xfile->swi_scM, new_script);
@@ -528,7 +549,7 @@ swi_parse_file(
 	ret = sw_yyparse(curfd, ofd, name, 0, SWPARSE_FORM_MKUP_LEN);
 	if (ret) {
 		fprintf(stderr,
-		"swbis: error parsing %s\n", name);
+		"%s: error parsing %s\n", swlib_utilname_get(), name);
 		swi_com_fatal_error( __FILE__, __LINE__);
 	}
 	uxfio_write(ofd, "\x00", 1);
@@ -550,7 +571,7 @@ swi_parse_file(
 			swi_com_assert_pointer(
 				(void*)(swi->swi_pkgM->current_xfileM),
 					__FILE__, __LINE__);
-			swi->swi_pkgM->current_xfileM->headerM = swheader;
+			swi->swi_pkgM->current_xfileM->info_headerM = swheader;
 			swi->swi_pkgM->current_xfileM->INFO_header_indexM = 0;
 			swi->swi_pkgM->current_xfileM->swdef_fdM = curfd;
 			swi->swi_pkgM->current_xfileM->did_parse_def_fileM = 1;
@@ -565,20 +586,21 @@ swi_parse_file(
 			break;
 		case SWPARSE_SWDEF_FILETYPE_INDEX:
 			SWSWI_E_DEBUG("case");
-			swi->swi_pkgM->headerM = swheader;
-			swi->swi_pkgM->header_indexM = 0;
+			swi->swi_pkgM->baseM.global_headerM = swheader;
+			swi->swi_pkgM->baseM.header_indexM = 0;
 			swi->swi_pkgM->swdef_fdM = curfd;
 			swi->swi_pkgM->did_parse_def_fileM = 1;
 			
 			swheader_set_current_offset_p(swheader, 
-					&(swi->swi_pkgM->header_indexM));
+					&(swi->swi_pkgM->baseM.header_indexM));
 			swheader_set_current_offset_p_value(swheader, 0);
 			swheader_reset(swheader);
 			swheader_goto_next_line(swheader,
 				swheader_get_current_offset_p(swheader),
 				SWHEADER_GET_NEXT);
 			
-			swi_get_distribution_attributes(swi, swheader);
+			if (swi_get_distribution_attributes(swi, swheader) != 0)
+				swi_com_fatal_error( __FILE__, __LINE__);
 			swpath_set_dfiles(swpath, 
 					swi->swi_pkgM->dfiles_attributeM);
 			swpath_set_pfiles(swpath, 
@@ -803,6 +825,7 @@ swi_decode_catalog(SWI * swi)
 
 	while(name) {
 		header_bytes = ret;
+		SWSWI_E_DEBUG("");
 		if (xformat_is_end_of_archive(xformat)){
 			/* 
 			 * error 
@@ -810,9 +833,7 @@ swi_decode_catalog(SWI * swi)
 			retval = -1;
 			break;
 		}
-/*
-fprintf(stderr, "JLJL name=[%s]\n", name);
-*/
+
 		/*
 		 * Check for absolute path, and for shell metacharacters
 		 * characters in the pathname.
@@ -821,7 +842,8 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 
 		swpath_ret = swpath_parse_path(swpath, name);
 		if (swpath_ret < 0) {
-			fprintf(stderr, "error parsing pathname [%s]\n", name);
+			SWSWI_E_DEBUG("");
+			fprintf(stderr, "%s: error parsing pathname [%s]\n", swlib_utilname_get(), name);
 			retval = -2;
 			break;
 		}
@@ -832,6 +854,7 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 			 * Either -1 leading dir, or 1 catalog.
 			 */
 			if (is_catalog == 1 && catalog_start_offset < 0) {
+				SWSWI_E_DEBUG("");
 				catalog_start_offset = offset;
 				swi->swi_pkgM->catalog_start_offsetM = offset;
 				/*
@@ -849,6 +872,7 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 				 * specified when being unpacked (by tar)
 				 * and deleted.
 				 */
+				SWSWI_E_DEBUG("");
 				strob_strcpy(tmp, swpath_get_prepath(swpath));
 				swlib_unix_dircat(tmp, SW_CATALOG);
 				swi->exported_catalog_prefixM = strdup(strob_str(tmp));
@@ -862,6 +886,7 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 				/*
 				 * error
 				 */	
+				SWSWI_E_DEBUG("");
 				swi_com_assert_pointer((void*)NULL, 
 						__FILE__, __LINE__);
 			}
@@ -869,6 +894,10 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 			if (swi_is_definition_file(swi, name, 
 							&swdeffile_type)) 
 			{
+				/*
+				 * parse the IEEE 1387.2 software definition file
+				 */
+				SWSWI_E_DEBUG("");
 				swdef_ret = swi_parse_file(swi, name, 
 							swdeffile_type);
 				if (swdef_ret) {
@@ -882,12 +911,14 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 				/*
 				 * Store the file data.
 				 */
+				SWSWI_E_DEBUG("");
 				swi_store_file(swi, name,
 					swi->swi_pkgM->current_xfileM);
 			} else {
 				/*
 				 * No data
 				 */
+				SWSWI_E_DEBUG("");
 				copyret = 0;	
 				;
 			}
@@ -895,10 +926,12 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 				/*
 				 * error
 				 */
+				SWSWI_E_DEBUG("");
 				SWI_internal_error();
 				retval = -4;
 				break;
 			}
+			SWSWI_E_DEBUG("");
 			catalog_end_offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);	
 			swi->swi_pkgM->catalog_end_offsetM = catalog_end_offset;
 		} else {
@@ -906,6 +939,7 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 			 * Good.
 			 * Finished, read past catalog section
 			 */
+			SWSWI_E_DEBUG("");
 			if (catalog_start_offset < 0) {
 				catalog_start_offset = 0;
 				fprintf(stderr, "internal error: %s:%d\n",
@@ -928,17 +962,24 @@ fprintf(stderr, "JLJL name=[%s]\n", name);
 
 			}
 			retval = 0;
+			SWSWI_E_DEBUG("");
 			break;
 		}
+		SWSWI_E_DEBUG("");
 		oldoffset = offset;
 		name = xformat_get_next_dirent(xformat, &st);
 		offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);
-		/* fprintf(stderr, "eraseme ayyyyyye %d\n",
-			xformat->swvarfsM->current_header_offsetM); */
+		SWSWI_E_DEBUG("");
 	}
 
-	swi_recurse_swi_tree(swi, (char *)(NULL), swi_base_update, NULL);
+	SWSWI_E_DEBUG("");
 
+	swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_set_verbose_level, (void*)(&(swi->verboseM)));
+	swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_update, NULL);
+	ret = swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_generate_swverid, NULL);
+	if (ret) {
+		if (retval == 0) retval = -1;
+	}
 	swi->swi_pkgM->is_minimal_layoutM = swpath_get_is_minimal_layout(swpath);
 	strob_close(tmp);
 	return retval;
@@ -1045,3 +1086,161 @@ swi_find_fileset_by_swsel(SWI_PRODUCT *  parent, char * swsel)
 	SWLIB_ASSERT(((SWI_XFILE*)base)->typeM == SWI_XFILE_TYPE_FILESET); 	
 	return (SWI_XFILE*)(base);
 }
+
+void
+swi_get_uts_attributes_from_current(SWI * swi, SWUTS * uts, SWHEADER * swheader)
+{
+	char * value;	
+
+	value = swheader_get_single_attribute_value(swheader, SW_A_os_name);
+	if (value) {
+		swuts_store_value(uts, uts->sysnameM, value);
+	} else {
+		swuts_store_value(uts, uts->sysnameM, "*");
+	}	
+
+	value = swheader_get_single_attribute_value(swheader, SW_A_os_version);
+	if (value) {
+		swuts_store_value(uts, uts->versionM, value);
+	} else {
+		swuts_store_value(uts, uts->versionM, "*");
+	}	
+
+	value = swheader_get_single_attribute_value(swheader, SW_A_os_release);
+	if (value) {
+		swuts_store_value(uts, uts->releaseM, value);
+	} else {
+		swuts_store_value(uts, uts->releaseM, "*");
+	}	
+
+	value = swheader_get_single_attribute_value(swheader, SW_A_machine_type);
+	if (value) {
+		swuts_store_value(uts, uts->machineM, value);
+	} else {
+		swuts_store_value(uts, uts->machineM, "*");
+	}	
+	return;
+}
+
+int
+swi_do_decode(SWI * swi, SWUTIL * swutil,
+	int target_fd1,
+	int source_fd0,
+	char * target_path,
+	char * source_path,
+	VPLOB * swspecs,
+	char * target_host,
+	struct extendedOptions * opta,
+	int is_seekable,
+	int do_debug_events,
+	int verboseG,
+	struct sw_logspec * g_logspec
+	)
+{
+	int ret;
+	int ifd;
+	int retval;
+	XFORMAT * xformat;
+	SWPATH * swpath;
+	UINFORMAT * uinformat;
+	SWVARFS * swvarfs;
+	char * rpm_newname;
+
+	SWLIB_ASSERT(source_fd0 >= 0);
+	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB,
+					g_logspec, swutil->swu_efdM, 
+					"run audit: start setup_xformat\n");
+
+	xformat = swutil_setup_xformat(swutil, target_fd1,
+			source_fd0, source_path, opta, is_seekable, verboseG, g_logspec);
+	if (!xformat) {
+		/* redundant LC_RAISE(SIGTERM); */
+		return -1;
+	}
+	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB2, g_logspec, swutil->swu_efdM, 
+				"run audit: finished setup_xformat\n");
+
+	SWLIB_ASSERT(xformat != (XFORMAT*)NULL);
+
+	xformat_set_ofd(xformat, target_fd1);
+
+	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB2, g_logspec, swutil->swu_efdM, 
+			"run audit: starting swlib_audit_distribution\n");
+
+	swvarfs = xformat_get_swvarfs(xformat);
+	uinformat = swvarfs_get_uinformat(swvarfs);
+	swpath = uinfile_get_swpath(uinformat);
+        swpath_reset(swpath);
+
+	xformat_set_tarheader_flag(xformat, TARU_TAR_FRAGILE_FORMAT, 1);
+	xformat_set_tarheader_flag(xformat, TARU_TAR_RETAIN_HEADER_IDS, 1);
+
+	/*
+	 * If translating an RPM, don't install the RPMFILE_CONFIG files
+	 */
+	if (uinfile_get_ztype(uinformat) == UINFILE_COMPRESSED_RPM) {
+		/*
+		 * we'er installing an RPM, yeah!!! ;)
+		 */
+		set_opta(opta, SW_E_swbis_install_volatile, "true");
+		rpm_newname = get_opta(opta, SW_E_swbis_volatile_newname);
+		if (
+			swextopt_is_option_set(SW_E_swbis_volatile_newname, opta) == 0 &&
+			(!rpm_newname || !strlen(rpm_newname))
+		) {
+			set_opta(opta, SW_E_swbis_volatile_newname, ".rpmnew");
+		} else {
+			;
+			/*
+			 * Use the one the user set.
+			 */
+		}
+	}
+
+	swi->xformatM = xformat; 
+	swi->swvarfsM = swvarfs; 
+	swi->uinformatM = uinformat;
+	swi->swpathM = swpath;   
+	swi->verboseM = verboseG;
+	if (target_host) {
+		swi->swi_pkgM->target_hostM = strdup(target_host);
+	} else {
+		swi->swi_pkgM->target_hostM = strdup("localhost");
+	}	
+	ifd = xformat_get_ifd(xformat);	
+	swi->optaM = (void*)opta;
+	swi->swc_idM = SWC_I; 	/* swinstall */
+	swi->debug_eventsM = do_debug_events;
+	
+	/*
+	 * Decode the catalog section.
+	 */
+	ret = swi_decode_catalog(swi);
+
+	/*
+	 * Set the auto disable of the memory cache.
+	 * This will turn off memory cache as soon as the
+	 * file advances beyond the previous farthest point
+	 */
+	swvarfs_uxfio_fcntl(swvarfs, UXFIO_F_ARM_AUTO_DISABLE, 1);
+
+	/*
+	 * Now seek back to the beginning of the package.
+	 */
+	if (uxfio_lseek(ifd, 0, SEEK_SET) != 0) {
+		fprintf(stderr, "uxfio_lseek error: %s : %d\n", __FILE__, __LINE__);
+		exit(1);
+	}
+
+        swpath_reset(swpath);
+	if (ret) {
+		/*
+		* error, swi_decode_catalog failed
+		*/
+		retval = -1;
+		swi = (SWI*)(NULL);
+	} else {
+		retval = 0;
+	}
+	return retval;
+}
