@@ -41,10 +41,11 @@
 #include "swi_common.h"
 #include "swi_afile.h"
 #include "swi_xfile.h"
+#include "swverid.h"
 
 
 #define SWI_GET_PRODUCT(W, N) (swi_package_get_product(W->swi_pkgM, N))
-#define SWI_INDEX_HEADER(W) (W->swi_pkgM->headerM)
+#define SWI_INDEX_HEADER(W) (W->swi_pkgM->baseM.global_headerM)
 
 
 typedef struct {		/* the Bundle structure			*/
@@ -56,18 +57,7 @@ typedef struct {		/* the Bundle structure			*/
 } SWI_BUNDLE;
 
 typedef struct {		/* the Product structure		*/
-
-				/* This *Must* match SWI_BASE		*/
-	unsigned char id_startM;  /* Always SWI_BASE_ID_BEGIN */
-	char type_idM;		/* 'P'					*/
-	int is_activeM;		
-	char * tagM;		/* the product tag			*/
-	time_t create_timeM;
-	time_t mod_timeM;
-	int header_indexM;	/* index in the global INDEX file       */
-	SWHEADER  * global_indexM;	/* Global INDEX access object	*/
-	unsigned char id_endM; /* Always SWI_BASE_ID_END */
-				/* End of what *Must* match SWI_BASE	*/
+	SWI_BASE baseM;
 
 	SWI_XFILE * swi_coM[SWI_MAX_OBJ];  /* list of filesets  	*/
 	char * package_pathM;	/* The package path for this object	*/
@@ -75,22 +65,11 @@ typedef struct {		/* the Product structure		*/
 	SWI_XFILE * pfilesM;
 	STRAR * filesetsM;	/* list of installed filesets		*/
 	int is_selectedM;	/* is selected				*/
-	int INDEX_ordinalM;      /* Order in INDEX file.  0 is first     */      
+	int INDEX_ordinalM;     /* Order in INDEX file.  0 is first     */      
 } SWI_PRODUCT;
 
 typedef struct {			/* The global package structure	*/
-
-				/* This *Must* match SWI_BASE		*/
-	unsigned char id_startM;  /* Always SWI_BASE_ID_BEGIN */
-	char type_idM;		/* 'P'					*/
-	int is_activeM;		
-	char * tagM;		/* the product tag			*/
-	time_t create_timeM;
-	time_t mod_timeM;
-	int header_indexM;	/* index in the global INDEX file       */
-	SWHEADER  * headerM;	/* Global INDEX access object	*/
-	unsigned char id_endM; /* Always SWI_BASE_ID_END */
-				/* End of what *Must* match SWI_BASE	*/
+	SWI_BASE baseM;
 
 	SWI_PRODUCT * swi_coM[SWI_MAX_OBJ];	/* List of products	*/
 	SWI_SCRIPTS * swi_scM;		/* control scripts 		*/
@@ -144,6 +123,7 @@ typedef struct {	/* The Global package control structure */
 	void * optaM;		/* extended options structure		*/
 	int swc_idM;		/* SWC_?   which utility		*/ 
 	int debug_eventsM;      /*                                      */
+	SWVERID * version_idM;  /* target Version Id                    */
 } SWI;
 
 void swi_base_set_is_active(SWI_BASE * base, int n);
@@ -193,5 +173,18 @@ SWI_CONTROL_SCRIPT * swi_product_get_control_script_by_tag(SWI_PRODUCT * prod, c
 int swi_recurse_swi_tree(SWI * swi, char * sw_selections, int (*payload)(void*, void * uptr), void * uptr);
 SWI_PRODUCT * swi_find_product_by_swsel(SWI_PACKAGE * parent, char * swsel);
 SWI_XFILE * swi_find_fileset_by_swsel(SWI_PRODUCT * parent, char * swsel);
+void swi_get_uts_attributes_from_current(SWI * swi, SWUTS * uts, SWHEADER * swheader);
 
+int swi_do_decode(SWI * swi, SWUTIL * swutil,
+	int target_fd1,
+	int source_fd0,
+	char * target_path,
+	char * source_path,
+	VPLOB * swpsecs,
+	char * target_host,
+	struct extendedOptions * opta,
+	int is_seekable,
+	int do_debug_events,
+	int verboseG,
+	struct sw_logspec * g_logspec);
 #endif
