@@ -73,7 +73,7 @@ swi_xfile_member_dump_string_s(SWI_FILE_MEMBER * xx, char * prefix)
 
 	strob_sprintf(buf, 0, "%s%p (SWI_FILE_MEMBER*)\n", prefix,  (void*)xx);
 	strob_sprintf(buf, 1, "%s%p->pathnameM       = [%s]\n", prefix, (void*)xx,  xx->pathnameM);
-	strob_sprintf(buf, 1, "%s%p->is_activeM      = [%d]\n", prefix, (void*)xx,  xx->is_activeM);
+	strob_sprintf(buf, 1, "%s%p->is_activeM      = [%d]\n", prefix, (void*)xx,  xx->baseM.is_activeM);
 	strob_sprintf(buf, 1, "%s%p->lenM            = [%d]\n", prefix, (void*)xx,  xx->lenM);
 	strob_sprintf(buf, 1, "%s%p->dataM T>>>>>> BEGIN DATA\n", prefix, (void*)xx);
 	datap = xx->dataM;
@@ -118,8 +118,8 @@ swi_xfile_script_dump_string_s(SWI_CONTROL_SCRIPT * xx, char * prefix)
 	buf = buf2;
 
 	strob_sprintf(buf, 0, "%s%p (SWI_CONTROL_SCRIPT*)\n", prefix,  (void*)xx);
-	strob_sprintf(buf, 1, "%s%p->is_activeM  = [%d]\n", prefix, (void*)xx,  xx->is_activeM);
-	strob_sprintf(buf, 1, "%s%p->tagM        = [%s]\n", prefix, (void*)xx,  xx->tagM);
+	strob_sprintf(buf, 1, "%s%p->is_activeM  = [%d]\n", prefix, (void*)xx,  xx->baseM.is_activeM);
+	strob_sprintf(buf, 1, "%s%p->tagM        = [%s]\n", prefix, (void*)xx,  xx->baseM.tagM);
 	strob_sprintf(buf, 1, "%s%p->resultM     = [%d]\n", prefix, (void*)xx,  xx->resultM);
 	strob_sprintf(buf, 1, "%s%p->afileM      = [%p]\n", prefix, (void*)xx,  xx->afileM);
 	tmps = swi_xfile_member_dump_string_s(xx->afileM, prefix);
@@ -144,11 +144,11 @@ swi_xfile_dump_string_s(SWI_XFILE * xx, char * prefix)
 	strob_sprintf(buf, 1, "%s%p->typeM           = [%d]\n", prefix, (void*)xx,  xx->typeM);
 	strob_sprintf(buf, 1, "%s%p->package_pathM   = [%s]\n", prefix, (void*)xx,  xx->package_pathM);
 	strob_sprintf(buf, 1, "%s%p->control_dirM    = [%s]\n", prefix, (void*)xx,  xx->control_dirM);
-	strob_sprintf(buf, 1, "%s%p->tagM            = [%s]\n", prefix, (void*)xx,  xx->tagM);
+	strob_sprintf(buf, 1, "%s%p->baseM.tagM            = [%s]\n", prefix, (void*)xx,  xx->baseM.tagM);
 	strob_sprintf(buf, 1, "%s%p->swi_scM         = [%p]\n", prefix, (void*)xx,  xx->swi_scM);
-	strob_sprintf(buf, 1, "%s%p->headerM         = [%p]\n", prefix, (void*)xx,  xx->headerM);
+	strob_sprintf(buf, 1, "%s%p->headerM         = [%p]\n", prefix, (void*)xx,  xx->info_headerM);
 	strob_sprintf(buf, 1, "%s%p->INFO_header_indexM   = [%d]\n", prefix, (void*)xx,  xx->INFO_header_indexM);
-	strob_sprintf(buf, 1, "%s%p->INDEX_header_indexM   = [%d]\n", prefix, (void*)xx,  xx->INDEX_header_indexM);
+	strob_sprintf(buf, 1, "%s%p->INDEX_header_indexM   = [%d]\n", prefix, (void*)xx,  xx->baseM.header_indexM);
 	strob_sprintf(buf, 1, "%s%p->archive_filesM  = [%p]\n", prefix, (void*)xx,  xx->archive_filesM);
 	strob_sprintf(buf, 1, "%s%p->swdef_fdM       = [%d]\n",  prefix, (void*)xx,  xx->swdef_fdM);
 	strob_sprintf(buf, 1, "%s%p->did_parse_def_fileM = [%d]\n",  prefix, (void*)xx,  xx->did_parse_def_fileM);
@@ -193,7 +193,7 @@ swi_product_dump_string_s(SWI_PRODUCT * xx, char * prefix)
 	strob_sprintf(buf, 0, "%s%p (SWI_PRODUCT*)\n", prefix,  (void*)xx);
 	strob_sprintf(buf, 1, "%s%p->package_pathM   = [%s]\n", prefix, (void*)xx,  xx->package_pathM);
 	strob_sprintf(buf, 1, "%s%p->control_dirM    = [%s]\n", prefix, (void*)xx,  xx->control_dirM);
-	strob_sprintf(buf, 1, "%s%p->tagM            = [%s]\n", prefix, (void*)xx,  xx->tagM);
+	strob_sprintf(buf, 1, "%s%p->baseM.tagM            = [%s]\n", prefix, (void*)xx,  xx->baseM.tagM);
 	strob_sprintf(buf, 1, "%s%p->pfilesM         = [%p]\n", prefix, (void*)xx,  (void*)(xx->pfilesM));
 	
 	strob_sprintf(buf, 1, "%s%p->pfilesM         = [%p] (BEGIN PFILES)\n",
