@@ -149,11 +149,6 @@ taru_set_tarheader_flag(TARU * taru, int flag, int n) {
 void
 taru_set_preview_level(TARU * taru, int preview_level)
 {
-	/*
-	fprintf(stderr, "HEREERERR %p  level=%d\n", taru, preview_level);
-	taru->preview_levelM = 0;
-	return;
-	*/
 	taru->preview_levelM = preview_level;
 }
 
@@ -190,7 +185,13 @@ taru_print_tar_ls_list(STROB * buf, struct new_cpio_header * file_hdr, int vflag
 	strob_strcpy(buf, "");
 	taru_filehdr2statbuf(&sbp, file_hdr);
 	type = taru_get_tar_filetype(file_hdr->c_mode);
-	if (file_hdr->c_is_tar_lnktype == 1) {
+	if (
+		(file_hdr->c_is_tar_lnktype == 1) ||
+		(
+			type == REGTYPE &&
+			strlen(ahsStaticGetTarLinkname(file_hdr))
+		)
+	) {
 		type = LNKTYPE;
 	}
 	ls_list_to_string(
