@@ -452,7 +452,6 @@ read_catalog_section(void * vp, int ifd)
 {
 	XFORMAT * package = (XFORMAT *)vp;
 	int nullfd;
-	int passfd;
 	int copyret;
 	int ret;
 	int retval = 0;
@@ -461,8 +460,6 @@ read_catalog_section(void * vp, int ifd)
 	STROB * namebuf = strob_open(100);
 	char * name;
 	SWPATH * swpath = swpath_open("");
-	int debug = 0;
-	int do_adjunct = 0;
 	int header_bytes;
 
 	TARUIB_E_DEBUG("ENTERING");
@@ -553,7 +550,6 @@ taruib_write_signedfile_if_i(void * vp, int ofd,
 	int header_bytes;
 	int pattern_code = 0;
 	int verbose = 1;
-	int ofd2 = -1;
 	int path_ret;
 	int detected_pattern_code;
 	STROB * namebuf = strob_open(100);
@@ -1189,10 +1185,8 @@ taruib_arfinstall(void * xswi, void * xpackage,
 		void (*alarm_handler)(int),
 		void * xselections)
 {
-	SWI * swi = (SWI*)xswi;
 	XFORMAT * package = (XFORMAT*)xpackage;
 	SWPATH * swpath = (SWPATH*)xswpath;
-	STRAR * selections = (STRAR*)xselections;
 	int nullfd;
 	int format;
 	int output_format;
@@ -1201,9 +1195,6 @@ taruib_arfinstall(void * xswi, void * xpackage,
 	int ret;
 	int aret;
 	int parseret;
-	int bytesret;
-	int is_dir;
-	int is_symlink;
 	int pathret;
 	int retval = -1;
 	int depth;
