@@ -668,7 +668,7 @@ xformat_set_preview_level(XFORMAT * xux, int fd)
 { 
 	XFORMAT_E_DEBUG("");
 	if (!(xux->taruM)) {
-		fprintf(stderr, "JLJL %d AAAAAAAArRRRRRRRGGGGGGGg\n", __LINE__);
+		fprintf(stderr, "JLJL AAARRRRGG at line %d\n", __LINE__);
 		return;
 	}
 	taru_set_preview_level(xux->taruM, fd);
@@ -679,7 +679,7 @@ xformat_set_preview_fd(XFORMAT * xux, int fd)
 { 
 	XFORMAT_E_DEBUG("");
 	if (!(xux->taruM)) {
-		fprintf(stderr, "JLJL %d AAAAAAAArRRRRRRRGGGGGGGg\n", __LINE__);
+		fprintf(stderr, "JLJL AAARRRRGG at line %d\n", __LINE__);
 		return;
 	}
 	taru_set_preview_fd(xux->taruM, fd);
@@ -1100,7 +1100,9 @@ xformat_u_open_file(XFORMAT * xux, char * name)
 	int fd = swvarfs_u_open(xux->swvarfsM, name);
 	
 	XFORMAT_E_DEBUG("");
-	if (fd <= 0) return fd;
+	if (fd <= 0) {
+		return fd;
+	}
 	fd = u_open_file_common(xux, fd);
 	XFORMAT_E_DEBUG("LEAVING");
 	return fd;
