@@ -2,8 +2,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "swparser_global.h"
 #include "swlib.h"
+#include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 int main (int argc, char ** argv)
 {
