@@ -6,6 +6,8 @@
 #include "swlib.h"
 #include "swvarfs.h"
 #include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 
 int 
