@@ -14,6 +14,8 @@
 #include "swparser_global.h"
 #include "swlib.h"
 #include "shcmd.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 int
 main (int argc, char ** argv)
