@@ -9,6 +9,10 @@ static char testpath_cxx[] =
 #include "taru.h"
 #include "swpath.h"
 #include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 #define LINELEN 900
 
