@@ -705,7 +705,7 @@ LABEL_REREAD:
 				4 + /* member payload length i.e. "2.0\n" */
 				TARU_AR_SIZE_OFFSET );
 
-		control_gz_size = atoi(s_size);
+		control_gz_size = swlib_atoi(s_size, NULL);
 
 		if (control_gz_size <= 0 || control_gz_size > 100000000) {
 			/*
