@@ -16,7 +16,7 @@ static char testswdefinitionwrite_cxx[] =
 #include "swdefinitionfile.h"
 #include "swexdistribution.h"
 
-#include "swparser_global.h"
+#include "swmain.h"
 
 int
 main (void)
