@@ -30,8 +30,7 @@
 #include "switer.h"
 #include "swstructiter.h"
 #include "swspsf.h"
-
-#include "swparser_global.h"
+#include "swmain.h"
 
 extern "C" {
 #include "swparser_global.h"
@@ -574,7 +573,7 @@ main(int argc, char **argv)
 			fprintf(stdout,"find keyword in current object sws=%p\n", (void*)sws);
 			/* switer->reset(); */
 			fprintf(stdout,"enter keyword: <%s> ", keyword); get_string(keyword);
-			obj=swheader_get_attribute_single_value(swheader, keyword);
+			obj=swheader_get_attribute(swheader, keyword);
 			if (!obj) {
 				fprintf(stderr, "not found.\n");
 			} else {
