@@ -25,8 +25,7 @@
 #include "swdefinition.h"
 #include "swdefinitionfile.h"
 #include "swpsf.h"
-
-#include "swparser_global.h"
+#include "swmain.h"
 
 extern "C" {
 #include "swparser_global.h"
@@ -438,7 +437,7 @@ main(int argc, char **argv)
 			
 			fprintf(stdout,"find keyword in current object swm=%p\n", (void*)swm);
 			fprintf(stdout,"enter keyword: <%s> ", keyword); get_string(keyword);
-			obj=swheader_get_attribute_single_value(swheader, keyword);
+			obj=swheader_get_attribute(swheader, keyword);
 			if (!obj) {
 				fprintf(stderr, "not found.\n");
 			} else {
