@@ -9,10 +9,10 @@ static char testpath_cxx[] =
 #include <string>
 #include <typeinfo>
 #include "stream_config.h"
-#include "swparser_global.h"
 #include "swdeffile.h"
 #include "swparser.h"
 #include "swpathname.h"
+#include "swmain.h"
 
 int
 main (int argc, char ** argv)
