@@ -6,14 +6,16 @@ static char testpath_cxx[] =
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <string>
+#include <string.h>
+#include <unistd.h>
 #include <typeinfo>
 #include "stream_config.h"
-extern "C" {
-#include "strob.h"
-}
-
 #include "swpathname.h"
+#include "swmain.h"
+
+extern "C" {
+#include "swlib.h"
+}
 
 int
 main (int argc, char ** argv)
