@@ -13,7 +13,7 @@ static char testswdefinitionwrite_cxx[] =
 #include "swparser.h"
 #include "swpsf.h"
 
-#include "swparser_global.h"
+#include "swmain.h"
 
 int
 main (void)
