@@ -12,9 +12,8 @@ static char testswdefinitionwrite_cxx[] =
 #include <assert.h>
 #include "swindex.h"
 #include "swparser.h"
-
-#include "swparser_global.h"
-  
+#include "swmain.h"
+ 
   
 int  
 main (void)
