@@ -12,8 +12,7 @@ static char testswdefinitionwrite_cxx[] =
 #include "stream_config.h"
 #include "swparser.h"
 #include "swpsf.h"
-
-#include "swparser_global.h"
+#include "swmain.h"
 
 int
 main (int argc, char ** argv)
