@@ -11,8 +11,7 @@ static char testswdefinitionwrite_cxx[] =
 #include <typeinfo>
 #include "stream_config.h"
 #include "swpsf.h"
-
-#include "swparser_global.h"
+#include "swmain.h"
 
 int
 main (int argc, char ** argv)
