@@ -15,7 +15,7 @@ static char testswdefinitionwrite_cxx[] =
 #include "swindex.h"
 #include "swpackagefile.h"
 
-#include "swparser_global.h"
+#include "swmain.h"
 
 int
 main (int argc, char ** argv)
