@@ -9,15 +9,15 @@ static char testswdefinitionwrite_cxx[] =
 #include <string>
 #include <typeinfo>
 #include "stream_config.h"
+#include "swparser.h"
 #include "swstruct.h"
+#include "swspsf.h"
 #include "swstruct_i.h"
 #include "swdefinition.h"
-#include "swpsf.h"
-#include "swspsf.h"
+#include "swscollection.h"
 #include "swdefinitionfile.h"
-#include "swparser.h"
-
-#include "swparser_global.h"
+#include "swpsf.h"
+#include "swmain.h"
 
 int
 main (void)
