@@ -17,7 +17,7 @@ static char testswdefinitionwrite_cxx[] =
 #include "swdefinitionfile.h"
 #include "swparser.h"
 
-#include "swparser_global.h"
+#include "swmain.h"
 
 int
 main (void)
